from typing import Any, Dict, Type, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="BasePluginConfiguration")


@_attrs_define
class BasePluginConfiguration:
    """Class BasePluginConfiguration."""

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        src_dict.copy()
        base_plugin_configuration = cls()

        return base_plugin_configuration



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.media_protocol import MediaProtocol
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.device_profile import DeviceProfile


T = TypeVar("T", bound="OpenLiveStreamDto")


@_attrs_define
class OpenLiveStreamDto:
    """Open live stream dto.

    Attributes:
        open_token (Union[Unset, None, str]): Gets or sets the open token.
        user_id (Union[Unset, None, str]): Gets or sets the user id.
        play_session_id (Union[Unset, None, str]): Gets or sets the play session id.
        max_streaming_bitrate (Union[Unset, None, int]): Gets or sets the max streaming bitrate.
        start_time_ticks (Union[Unset, None, int]): Gets or sets the start time in ticks.
        audio_stream_index (Union[Unset, None, int]): Gets or sets the audio stream index.
        subtitle_stream_index (Union[Unset, None, int]): Gets or sets the subtitle stream index.
        max_audio_channels (Union[Unset, None, int]): Gets or sets the max audio channels.
        item_id (Union[Unset, None, str]): Gets or sets the item id.
        enable_direct_play (Union[Unset, None, bool]): Gets or sets a value indicating whether to enable direct play.
        enable_direct_stream (Union[Unset, None, bool]): Gets or sets a value indicating whether to enale direct stream.
        device_profile (Union[Unset, None, DeviceProfile]): A MediaBrowser.Model.Dlna.DeviceProfile represents a set of
            metadata which determines which content a certain device is able to play.
            <br />
            Specifically, it defines the supported <see
            cref="P:MediaBrowser.Model.Dlna.DeviceProfile.ContainerProfiles">containers</see> and
            <see cref="P:MediaBrowser.Model.Dlna.DeviceProfile.CodecProfiles">codecs</see> (video and/or audio, including
            codec profiles and levels)
            the device is able to direct play (without transcoding or remuxing),
            as well as which <see cref="P:MediaBrowser.Model.Dlna.DeviceProfile.TranscodingProfiles">containers/codecs to
            transcode to</see> in case it isn't.
        direct_play_protocols (Union[Unset, List[MediaProtocol]]): Gets or sets the device play protocols.
    """

    open_token: Union[Unset, None, str] = UNSET
    user_id: Union[Unset, None, str] = UNSET
    play_session_id: Union[Unset, None, str] = UNSET
    max_streaming_bitrate: Union[Unset, None, int] = UNSET
    start_time_ticks: Union[Unset, None, int] = UNSET
    audio_stream_index: Union[Unset, None, int] = UNSET
    subtitle_stream_index: Union[Unset, None, int] = UNSET
    max_audio_channels: Union[Unset, None, int] = UNSET
    item_id: Union[Unset, None, str] = UNSET
    enable_direct_play: Union[Unset, None, bool] = UNSET
    enable_direct_stream: Union[Unset, None, bool] = UNSET
    device_profile: Union[Unset, None, "DeviceProfile"] = UNSET
    direct_play_protocols: Union[Unset, List[MediaProtocol]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        open_token = self.open_token
        user_id = self.user_id
        play_session_id = self.play_session_id
        max_streaming_bitrate = self.max_streaming_bitrate
        start_time_ticks = self.start_time_ticks
        audio_stream_index = self.audio_stream_index
        subtitle_stream_index = self.subtitle_stream_index
        max_audio_channels = self.max_audio_channels
        item_id = self.item_id
        enable_direct_play = self.enable_direct_play
        enable_direct_stream = self.enable_direct_stream
        device_profile: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.device_profile, Unset):
            device_profile = self.device_profile.to_dict() if self.device_profile else None

        direct_play_protocols: Union[Unset, List[str]] = UNSET
        if not isinstance(self.direct_play_protocols, Unset):
            direct_play_protocols = []
            for direct_play_protocols_item_data in self.direct_play_protocols:
                direct_play_protocols_item = direct_play_protocols_item_data.value

                direct_play_protocols.append(direct_play_protocols_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if open_token is not UNSET:
            field_dict["OpenToken"] = open_token
        if user_id is not UNSET:
            field_dict["UserId"] = user_id
        if play_session_id is not UNSET:
            field_dict["PlaySessionId"] = play_session_id
        if max_streaming_bitrate is not UNSET:
            field_dict["MaxStreamingBitrate"] = max_streaming_bitrate
        if start_time_ticks is not UNSET:
            field_dict["StartTimeTicks"] = start_time_ticks
        if audio_stream_index is not UNSET:
            field_dict["AudioStreamIndex"] = audio_stream_index
        if subtitle_stream_index is not UNSET:
            field_dict["SubtitleStreamIndex"] = subtitle_stream_index
        if max_audio_channels is not UNSET:
            field_dict["MaxAudioChannels"] = max_audio_channels
        if item_id is not UNSET:
            field_dict["ItemId"] = item_id
        if enable_direct_play is not UNSET:
            field_dict["EnableDirectPlay"] = enable_direct_play
        if enable_direct_stream is not UNSET:
            field_dict["EnableDirectStream"] = enable_direct_stream
        if device_profile is not UNSET:
            field_dict["DeviceProfile"] = device_profile
        if direct_play_protocols is not UNSET:
            field_dict["DirectPlayProtocols"] = direct_play_protocols

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.device_profile import DeviceProfile

        d = src_dict.copy()
        open_token = d.pop("OpenToken", UNSET)

        user_id = d.pop("UserId", UNSET)

        play_session_id = d.pop("PlaySessionId", UNSET)

        max_streaming_bitrate = d.pop("MaxStreamingBitrate", UNSET)

        start_time_ticks = d.pop("StartTimeTicks", UNSET)

        audio_stream_index = d.pop("AudioStreamIndex", UNSET)

        subtitle_stream_index = d.pop("SubtitleStreamIndex", UNSET)

        max_audio_channels = d.pop("MaxAudioChannels", UNSET)

        item_id = d.pop("ItemId", UNSET)

        enable_direct_play = d.pop("EnableDirectPlay", UNSET)

        enable_direct_stream = d.pop("EnableDirectStream", UNSET)

        _device_profile = d.pop("DeviceProfile", UNSET)
        device_profile: Union[Unset, None, DeviceProfile]
        if _device_profile is None:
            device_profile = None
        elif isinstance(_device_profile, Unset):
            device_profile = UNSET
        else:
            device_profile = DeviceProfile.from_dict(_device_profile)

        direct_play_protocols = []
        _direct_play_protocols = d.pop("DirectPlayProtocols", UNSET)
        for direct_play_protocols_item_data in _direct_play_protocols or []:
            direct_play_protocols_item = MediaProtocol(direct_play_protocols_item_data)

            direct_play_protocols.append(direct_play_protocols_item)

        open_live_stream_dto = cls(
            open_token=open_token,
            user_id=user_id,
            play_session_id=play_session_id,
            max_streaming_bitrate=max_streaming_bitrate,
            start_time_ticks=start_time_ticks,
            audio_stream_index=audio_stream_index,
            subtitle_stream_index=subtitle_stream_index,
            max_audio_channels=max_audio_channels,
            item_id=item_id,
            enable_direct_play=enable_direct_play,
            enable_direct_stream=enable_direct_stream,
            device_profile=device_profile,
            direct_play_protocols=direct_play_protocols,
        )

        return open_live_stream_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ItemCounts")


@_attrs_define
class ItemCounts:
    """Class LibrarySummary.

    Attributes:
        movie_count (Union[Unset, int]): Gets or sets the movie count.
        series_count (Union[Unset, int]): Gets or sets the series count.
        episode_count (Union[Unset, int]): Gets or sets the episode count.
        artist_count (Union[Unset, int]): Gets or sets the artist count.
        program_count (Union[Unset, int]): Gets or sets the program count.
        trailer_count (Union[Unset, int]): Gets or sets the trailer count.
        song_count (Union[Unset, int]): Gets or sets the song count.
        album_count (Union[Unset, int]): Gets or sets the album count.
        music_video_count (Union[Unset, int]): Gets or sets the music video count.
        box_set_count (Union[Unset, int]): Gets or sets the box set count.
        book_count (Union[Unset, int]): Gets or sets the book count.
        item_count (Union[Unset, int]): Gets or sets the item count.
    """

    movie_count: Union[Unset, int] = UNSET
    series_count: Union[Unset, int] = UNSET
    episode_count: Union[Unset, int] = UNSET
    artist_count: Union[Unset, int] = UNSET
    program_count: Union[Unset, int] = UNSET
    trailer_count: Union[Unset, int] = UNSET
    song_count: Union[Unset, int] = UNSET
    album_count: Union[Unset, int] = UNSET
    music_video_count: Union[Unset, int] = UNSET
    box_set_count: Union[Unset, int] = UNSET
    book_count: Union[Unset, int] = UNSET
    item_count: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        movie_count = self.movie_count
        series_count = self.series_count
        episode_count = self.episode_count
        artist_count = self.artist_count
        program_count = self.program_count
        trailer_count = self.trailer_count
        song_count = self.song_count
        album_count = self.album_count
        music_video_count = self.music_video_count
        box_set_count = self.box_set_count
        book_count = self.book_count
        item_count = self.item_count

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if movie_count is not UNSET:
            field_dict["MovieCount"] = movie_count
        if series_count is not UNSET:
            field_dict["SeriesCount"] = series_count
        if episode_count is not UNSET:
            field_dict["EpisodeCount"] = episode_count
        if artist_count is not UNSET:
            field_dict["ArtistCount"] = artist_count
        if program_count is not UNSET:
            field_dict["ProgramCount"] = program_count
        if trailer_count is not UNSET:
            field_dict["TrailerCount"] = trailer_count
        if song_count is not UNSET:
            field_dict["SongCount"] = song_count
        if album_count is not UNSET:
            field_dict["AlbumCount"] = album_count
        if music_video_count is not UNSET:
            field_dict["MusicVideoCount"] = music_video_count
        if box_set_count is not UNSET:
            field_dict["BoxSetCount"] = box_set_count
        if book_count is not UNSET:
            field_dict["BookCount"] = book_count
        if item_count is not UNSET:
            field_dict["ItemCount"] = item_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        movie_count = d.pop("MovieCount", UNSET)

        series_count = d.pop("SeriesCount", UNSET)

        episode_count = d.pop("EpisodeCount", UNSET)

        artist_count = d.pop("ArtistCount", UNSET)

        program_count = d.pop("ProgramCount", UNSET)

        trailer_count = d.pop("TrailerCount", UNSET)

        song_count = d.pop("SongCount", UNSET)

        album_count = d.pop("AlbumCount", UNSET)

        music_video_count = d.pop("MusicVideoCount", UNSET)

        box_set_count = d.pop("BoxSetCount", UNSET)

        book_count = d.pop("BookCount", UNSET)

        item_count = d.pop("ItemCount", UNSET)

        item_counts = cls(
            movie_count=movie_count,
            series_count=series_count,
            episode_count=episode_count,
            artist_count=artist_count,
            program_count=program_count,
            trailer_count=trailer_count,
            song_count=song_count,
            album_count=album_count,
            music_video_count=music_video_count,
            box_set_count=box_set_count,
            book_count=book_count,
            item_count=item_count,
        )

        return item_counts



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="PlayRequestDto")


@_attrs_define
class PlayRequestDto:
    """Class PlayRequestDto.

    Attributes:
        playing_queue (Union[Unset, List[str]]): Gets or sets the playing queue.
        playing_item_position (Union[Unset, int]): Gets or sets the position of the playing item in the queue.
        start_position_ticks (Union[Unset, int]): Gets or sets the start position ticks.
    """

    playing_queue: Union[Unset, List[str]] = UNSET
    playing_item_position: Union[Unset, int] = UNSET
    start_position_ticks: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        playing_queue: Union[Unset, List[str]] = UNSET
        if not isinstance(self.playing_queue, Unset):
            playing_queue = self.playing_queue

        playing_item_position = self.playing_item_position
        start_position_ticks = self.start_position_ticks

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if playing_queue is not UNSET:
            field_dict["PlayingQueue"] = playing_queue
        if playing_item_position is not UNSET:
            field_dict["PlayingItemPosition"] = playing_item_position
        if start_position_ticks is not UNSET:
            field_dict["StartPositionTicks"] = start_position_ticks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        playing_queue = cast(List[str], d.pop("PlayingQueue", UNSET))

        playing_item_position = d.pop("PlayingItemPosition", UNSET)

        start_position_ticks = d.pop("StartPositionTicks", UNSET)

        play_request_dto = cls(
            playing_queue=playing_queue,
            playing_item_position=playing_item_position,
            start_position_ticks=start_position_ticks,
        )

        return play_request_dto



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="NetworkConfiguration")


@_attrs_define
class NetworkConfiguration:
    """Defines the Jellyfin.Networking.Configuration.NetworkConfiguration.

    Attributes:
        require_https (Union[Unset, bool]): Gets or sets a value indicating whether the server should force connections
            over HTTPS.
        certificate_path (Union[Unset, str]): Gets or sets the filesystem path of an X.509 certificate to use for SSL.
        certificate_password (Union[Unset, str]): Gets or sets the password required to access the X.509 certificate
            data in the file specified by Jellyfin.Networking.Configuration.NetworkConfiguration.CertificatePath.
        base_url (Union[Unset, str]): Gets or sets a value used to specify the URL prefix that your Jellyfin instance
            can be accessed at.
        public_https_port (Union[Unset, int]): Gets or sets the public HTTPS port.
        http_server_port_number (Union[Unset, int]): Gets or sets the HTTP server port number.
        https_port_number (Union[Unset, int]): Gets or sets the HTTPS server port number.
        enable_https (Union[Unset, bool]): Gets or sets a value indicating whether to use HTTPS.
        public_port (Union[Unset, int]): Gets or sets the public mapped port.
        u_pn_p_create_http_port_map (Union[Unset, bool]): Gets or sets a value indicating whether the http port should
            be mapped as part of UPnP automatic port forwarding.
        udp_port_range (Union[Unset, str]): Gets or sets the UDPPortRange.
        enable_ipv6 (Union[Unset, bool]): Gets or sets a value indicating whether gets or sets IPV6 capability.
        enable_ipv4 (Union[Unset, bool]): Gets or sets a value indicating whether gets or sets IPV4 capability.
        enable_ssdp_tracing (Union[Unset, bool]): Gets or sets a value indicating whether detailed SSDP logs are sent to
            the console/log.
            "Emby.Dlna": "Debug" must be set in logging.default.json for this property to have any effect.
        ssdp_tracing_filter (Union[Unset, str]): Gets or sets the SSDPTracingFilter
            Gets or sets a value indicating whether an IP address is to be used to filter the detailed ssdp logs that are
            being sent to the console/log.
            If the setting "Emby.Dlna": "Debug" msut be set in logging.default.json for this property to work.
        udp_send_count (Union[Unset, int]): Gets or sets the number of times SSDP UDP messages are sent.
        udp_send_delay (Union[Unset, int]): Gets or sets the delay between each groups of SSDP messages (in ms).
        ignore_virtual_interfaces (Union[Unset, bool]): Gets or sets a value indicating whether address names that match
            Jellyfin.Networking.Configuration.NetworkConfiguration.VirtualInterfaceNames should be Ignore for the purposes
            of binding.
        virtual_interface_names (Union[Unset, str]): Gets or sets a value indicating the interfaces that should be
            ignored. The list can be comma separated. <seealso
            cref="P:Jellyfin.Networking.Configuration.NetworkConfiguration.IgnoreVirtualInterfaces" />.
        gateway_monitor_period (Union[Unset, int]): Gets or sets the time (in seconds) between the pings of SSDP gateway
            monitor.
        enable_multi_socket_binding (Union[Unset, bool]): Gets a value indicating whether multi-socket binding is
            available.
        trust_all_ip6_interfaces (Union[Unset, bool]): Gets or sets a value indicating whether all IPv6 interfaces
            should be treated as on the internal network.
            Depending on the address range implemented ULA ranges might not be used.
        hd_homerun_port_range (Union[Unset, str]): Gets or sets the ports that HDHomerun uses.
        published_server_uri_by_subnet (Union[Unset, List[str]]): Gets or sets the PublishedServerUriBySubnet
            Gets or sets PublishedServerUri to advertise for specific subnets.
        auto_discovery_tracing (Union[Unset, bool]): Gets or sets a value indicating whether Autodiscovery tracing is
            enabled.
        auto_discovery (Union[Unset, bool]): Gets or sets a value indicating whether Autodiscovery is enabled.
        remote_ip_filter (Union[Unset, List[str]]): Gets or sets the filter for remote IP connectivity. Used in
            conjuntion with <seealso
            cref="P:Jellyfin.Networking.Configuration.NetworkConfiguration.IsRemoteIPFilterBlacklist" />.
        is_remote_ip_filter_blacklist (Union[Unset, bool]): Gets or sets a value indicating whether <seealso
            cref="P:Jellyfin.Networking.Configuration.NetworkConfiguration.RemoteIPFilter" /> contains a blacklist or a
            whitelist. Default is a whitelist.
        enable_u_pn_p (Union[Unset, bool]): Gets or sets a value indicating whether to enable automatic port forwarding.
        enable_remote_access (Union[Unset, bool]): Gets or sets a value indicating whether access outside of the LAN is
            permitted.
        local_network_subnets (Union[Unset, List[str]]): Gets or sets the subnets that are deemed to make up the LAN.
        local_network_addresses (Union[Unset, List[str]]): Gets or sets the interface addresses which Jellyfin will bind
            to. If empty, all interfaces will be used.
        known_proxies (Union[Unset, List[str]]): Gets or sets the known proxies. If the proxy is a network, it's added
            to the KnownNetworks.
        enable_published_server_uri_by_request (Union[Unset, bool]): Gets or sets a value indicating whether the
            published server uri is based on information in HTTP requests.
    """

    require_https: Union[Unset, bool] = UNSET
    certificate_path: Union[Unset, str] = UNSET
    certificate_password: Union[Unset, str] = UNSET
    base_url: Union[Unset, str] = UNSET
    public_https_port: Union[Unset, int] = UNSET
    http_server_port_number: Union[Unset, int] = UNSET
    https_port_number: Union[Unset, int] = UNSET
    enable_https: Union[Unset, bool] = UNSET
    public_port: Union[Unset, int] = UNSET
    u_pn_p_create_http_port_map: Union[Unset, bool] = UNSET
    udp_port_range: Union[Unset, str] = UNSET
    enable_ipv6: Union[Unset, bool] = UNSET
    enable_ipv4: Union[Unset, bool] = UNSET
    enable_ssdp_tracing: Union[Unset, bool] = UNSET
    ssdp_tracing_filter: Union[Unset, str] = UNSET
    udp_send_count: Union[Unset, int] = UNSET
    udp_send_delay: Union[Unset, int] = UNSET
    ignore_virtual_interfaces: Union[Unset, bool] = UNSET
    virtual_interface_names: Union[Unset, str] = UNSET
    gateway_monitor_period: Union[Unset, int] = UNSET
    enable_multi_socket_binding: Union[Unset, bool] = UNSET
    trust_all_ip6_interfaces: Union[Unset, bool] = UNSET
    hd_homerun_port_range: Union[Unset, str] = UNSET
    published_server_uri_by_subnet: Union[Unset, List[str]] = UNSET
    auto_discovery_tracing: Union[Unset, bool] = UNSET
    auto_discovery: Union[Unset, bool] = UNSET
    remote_ip_filter: Union[Unset, List[str]] = UNSET
    is_remote_ip_filter_blacklist: Union[Unset, bool] = UNSET
    enable_u_pn_p: Union[Unset, bool] = UNSET
    enable_remote_access: Union[Unset, bool] = UNSET
    local_network_subnets: Union[Unset, List[str]] = UNSET
    local_network_addresses: Union[Unset, List[str]] = UNSET
    known_proxies: Union[Unset, List[str]] = UNSET
    enable_published_server_uri_by_request: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        require_https = self.require_https
        certificate_path = self.certificate_path
        certificate_password = self.certificate_password
        base_url = self.base_url
        public_https_port = self.public_https_port
        http_server_port_number = self.http_server_port_number
        https_port_number = self.https_port_number
        enable_https = self.enable_https
        public_port = self.public_port
        u_pn_p_create_http_port_map = self.u_pn_p_create_http_port_map
        udp_port_range = self.udp_port_range
        enable_ipv6 = self.enable_ipv6
        enable_ipv4 = self.enable_ipv4
        enable_ssdp_tracing = self.enable_ssdp_tracing
        ssdp_tracing_filter = self.ssdp_tracing_filter
        udp_send_count = self.udp_send_count
        udp_send_delay = self.udp_send_delay
        ignore_virtual_interfaces = self.ignore_virtual_interfaces
        virtual_interface_names = self.virtual_interface_names
        gateway_monitor_period = self.gateway_monitor_period
        enable_multi_socket_binding = self.enable_multi_socket_binding
        trust_all_ip6_interfaces = self.trust_all_ip6_interfaces
        hd_homerun_port_range = self.hd_homerun_port_range
        published_server_uri_by_subnet: Union[Unset, List[str]] = UNSET
        if not isinstance(self.published_server_uri_by_subnet, Unset):
            published_server_uri_by_subnet = self.published_server_uri_by_subnet

        auto_discovery_tracing = self.auto_discovery_tracing
        auto_discovery = self.auto_discovery
        remote_ip_filter: Union[Unset, List[str]] = UNSET
        if not isinstance(self.remote_ip_filter, Unset):
            remote_ip_filter = self.remote_ip_filter

        is_remote_ip_filter_blacklist = self.is_remote_ip_filter_blacklist
        enable_u_pn_p = self.enable_u_pn_p
        enable_remote_access = self.enable_remote_access
        local_network_subnets: Union[Unset, List[str]] = UNSET
        if not isinstance(self.local_network_subnets, Unset):
            local_network_subnets = self.local_network_subnets

        local_network_addresses: Union[Unset, List[str]] = UNSET
        if not isinstance(self.local_network_addresses, Unset):
            local_network_addresses = self.local_network_addresses

        known_proxies: Union[Unset, List[str]] = UNSET
        if not isinstance(self.known_proxies, Unset):
            known_proxies = self.known_proxies

        enable_published_server_uri_by_request = self.enable_published_server_uri_by_request

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if require_https is not UNSET:
            field_dict["RequireHttps"] = require_https
        if certificate_path is not UNSET:
            field_dict["CertificatePath"] = certificate_path
        if certificate_password is not UNSET:
            field_dict["CertificatePassword"] = certificate_password
        if base_url is not UNSET:
            field_dict["BaseUrl"] = base_url
        if public_https_port is not UNSET:
            field_dict["PublicHttpsPort"] = public_https_port
        if http_server_port_number is not UNSET:
            field_dict["HttpServerPortNumber"] = http_server_port_number
        if https_port_number is not UNSET:
            field_dict["HttpsPortNumber"] = https_port_number
        if enable_https is not UNSET:
            field_dict["EnableHttps"] = enable_https
        if public_port is not UNSET:
            field_dict["PublicPort"] = public_port
        if u_pn_p_create_http_port_map is not UNSET:
            field_dict["UPnPCreateHttpPortMap"] = u_pn_p_create_http_port_map
        if udp_port_range is not UNSET:
            field_dict["UDPPortRange"] = udp_port_range
        if enable_ipv6 is not UNSET:
            field_dict["EnableIPV6"] = enable_ipv6
        if enable_ipv4 is not UNSET:
            field_dict["EnableIPV4"] = enable_ipv4
        if enable_ssdp_tracing is not UNSET:
            field_dict["EnableSSDPTracing"] = enable_ssdp_tracing
        if ssdp_tracing_filter is not UNSET:
            field_dict["SSDPTracingFilter"] = ssdp_tracing_filter
        if udp_send_count is not UNSET:
            field_dict["UDPSendCount"] = udp_send_count
        if udp_send_delay is not UNSET:
            field_dict["UDPSendDelay"] = udp_send_delay
        if ignore_virtual_interfaces is not UNSET:
            field_dict["IgnoreVirtualInterfaces"] = ignore_virtual_interfaces
        if virtual_interface_names is not UNSET:
            field_dict["VirtualInterfaceNames"] = virtual_interface_names
        if gateway_monitor_period is not UNSET:
            field_dict["GatewayMonitorPeriod"] = gateway_monitor_period
        if enable_multi_socket_binding is not UNSET:
            field_dict["EnableMultiSocketBinding"] = enable_multi_socket_binding
        if trust_all_ip6_interfaces is not UNSET:
            field_dict["TrustAllIP6Interfaces"] = trust_all_ip6_interfaces
        if hd_homerun_port_range is not UNSET:
            field_dict["HDHomerunPortRange"] = hd_homerun_port_range
        if published_server_uri_by_subnet is not UNSET:
            field_dict["PublishedServerUriBySubnet"] = published_server_uri_by_subnet
        if auto_discovery_tracing is not UNSET:
            field_dict["AutoDiscoveryTracing"] = auto_discovery_tracing
        if auto_discovery is not UNSET:
            field_dict["AutoDiscovery"] = auto_discovery
        if remote_ip_filter is not UNSET:
            field_dict["RemoteIPFilter"] = remote_ip_filter
        if is_remote_ip_filter_blacklist is not UNSET:
            field_dict["IsRemoteIPFilterBlacklist"] = is_remote_ip_filter_blacklist
        if enable_u_pn_p is not UNSET:
            field_dict["EnableUPnP"] = enable_u_pn_p
        if enable_remote_access is not UNSET:
            field_dict["EnableRemoteAccess"] = enable_remote_access
        if local_network_subnets is not UNSET:
            field_dict["LocalNetworkSubnets"] = local_network_subnets
        if local_network_addresses is not UNSET:
            field_dict["LocalNetworkAddresses"] = local_network_addresses
        if known_proxies is not UNSET:
            field_dict["KnownProxies"] = known_proxies
        if enable_published_server_uri_by_request is not UNSET:
            field_dict["EnablePublishedServerUriByRequest"] = enable_published_server_uri_by_request

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        require_https = d.pop("RequireHttps", UNSET)

        certificate_path = d.pop("CertificatePath", UNSET)

        certificate_password = d.pop("CertificatePassword", UNSET)

        base_url = d.pop("BaseUrl", UNSET)

        public_https_port = d.pop("PublicHttpsPort", UNSET)

        http_server_port_number = d.pop("HttpServerPortNumber", UNSET)

        https_port_number = d.pop("HttpsPortNumber", UNSET)

        enable_https = d.pop("EnableHttps", UNSET)

        public_port = d.pop("PublicPort", UNSET)

        u_pn_p_create_http_port_map = d.pop("UPnPCreateHttpPortMap", UNSET)

        udp_port_range = d.pop("UDPPortRange", UNSET)

        enable_ipv6 = d.pop("EnableIPV6", UNSET)

        enable_ipv4 = d.pop("EnableIPV4", UNSET)

        enable_ssdp_tracing = d.pop("EnableSSDPTracing", UNSET)

        ssdp_tracing_filter = d.pop("SSDPTracingFilter", UNSET)

        udp_send_count = d.pop("UDPSendCount", UNSET)

        udp_send_delay = d.pop("UDPSendDelay", UNSET)

        ignore_virtual_interfaces = d.pop("IgnoreVirtualInterfaces", UNSET)

        virtual_interface_names = d.pop("VirtualInterfaceNames", UNSET)

        gateway_monitor_period = d.pop("GatewayMonitorPeriod", UNSET)

        enable_multi_socket_binding = d.pop("EnableMultiSocketBinding", UNSET)

        trust_all_ip6_interfaces = d.pop("TrustAllIP6Interfaces", UNSET)

        hd_homerun_port_range = d.pop("HDHomerunPortRange", UNSET)

        published_server_uri_by_subnet = cast(List[str], d.pop("PublishedServerUriBySubnet", UNSET))

        auto_discovery_tracing = d.pop("AutoDiscoveryTracing", UNSET)

        auto_discovery = d.pop("AutoDiscovery", UNSET)

        remote_ip_filter = cast(List[str], d.pop("RemoteIPFilter", UNSET))

        is_remote_ip_filter_blacklist = d.pop("IsRemoteIPFilterBlacklist", UNSET)

        enable_u_pn_p = d.pop("EnableUPnP", UNSET)

        enable_remote_access = d.pop("EnableRemoteAccess", UNSET)

        local_network_subnets = cast(List[str], d.pop("LocalNetworkSubnets", UNSET))

        local_network_addresses = cast(List[str], d.pop("LocalNetworkAddresses", UNSET))

        known_proxies = cast(List[str], d.pop("KnownProxies", UNSET))

        enable_published_server_uri_by_request = d.pop("EnablePublishedServerUriByRequest", UNSET)

        network_configuration = cls(
            require_https=require_https,
            certificate_path=certificate_path,
            certificate_password=certificate_password,
            base_url=base_url,
            public_https_port=public_https_port,
            http_server_port_number=http_server_port_number,
            https_port_number=https_port_number,
            enable_https=enable_https,
            public_port=public_port,
            u_pn_p_create_http_port_map=u_pn_p_create_http_port_map,
            udp_port_range=udp_port_range,
            enable_ipv6=enable_ipv6,
            enable_ipv4=enable_ipv4,
            enable_ssdp_tracing=enable_ssdp_tracing,
            ssdp_tracing_filter=ssdp_tracing_filter,
            udp_send_count=udp_send_count,
            udp_send_delay=udp_send_delay,
            ignore_virtual_interfaces=ignore_virtual_interfaces,
            virtual_interface_names=virtual_interface_names,
            gateway_monitor_period=gateway_monitor_period,
            enable_multi_socket_binding=enable_multi_socket_binding,
            trust_all_ip6_interfaces=trust_all_ip6_interfaces,
            hd_homerun_port_range=hd_homerun_port_range,
            published_server_uri_by_subnet=published_server_uri_by_subnet,
            auto_discovery_tracing=auto_discovery_tracing,
            auto_discovery=auto_discovery,
            remote_ip_filter=remote_ip_filter,
            is_remote_ip_filter_blacklist=is_remote_ip_filter_blacklist,
            enable_u_pn_p=enable_u_pn_p,
            enable_remote_access=enable_remote_access,
            local_network_subnets=local_network_subnets,
            local_network_addresses=local_network_addresses,
            known_proxies=known_proxies,
            enable_published_server_uri_by_request=enable_published_server_uri_by_request,
        )

        return network_configuration



from enum import Enum


class ImageOrientation(str, Enum):
    BOTTOMLEFT = "BottomLeft"
    BOTTOMRIGHT = "BottomRight"
    LEFTBOTTOM = "LeftBottom"
    LEFTTOP = "LeftTop"
    RIGHTBOTTOM = "RightBottom"
    RIGHTTOP = "RightTop"
    TOPLEFT = "TopLeft"
    TOPRIGHT = "TopRight"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SubtitleOptions")


@_attrs_define
class SubtitleOptions:
    """
    Attributes:
        skip_if_embedded_subtitles_present (Union[Unset, bool]):
        skip_if_audio_track_matches (Union[Unset, bool]):
        download_languages (Union[Unset, None, List[str]]):
        download_movie_subtitles (Union[Unset, bool]):
        download_episode_subtitles (Union[Unset, bool]):
        open_subtitles_username (Union[Unset, None, str]):
        open_subtitles_password_hash (Union[Unset, None, str]):
        is_open_subtitle_vip_account (Union[Unset, bool]):
        require_perfect_match (Union[Unset, bool]):
    """

    skip_if_embedded_subtitles_present: Union[Unset, bool] = UNSET
    skip_if_audio_track_matches: Union[Unset, bool] = UNSET
    download_languages: Union[Unset, None, List[str]] = UNSET
    download_movie_subtitles: Union[Unset, bool] = UNSET
    download_episode_subtitles: Union[Unset, bool] = UNSET
    open_subtitles_username: Union[Unset, None, str] = UNSET
    open_subtitles_password_hash: Union[Unset, None, str] = UNSET
    is_open_subtitle_vip_account: Union[Unset, bool] = UNSET
    require_perfect_match: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        skip_if_embedded_subtitles_present = self.skip_if_embedded_subtitles_present
        skip_if_audio_track_matches = self.skip_if_audio_track_matches
        download_languages: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.download_languages, Unset):
            if self.download_languages is None:
                download_languages = None
            else:
                download_languages = self.download_languages

        download_movie_subtitles = self.download_movie_subtitles
        download_episode_subtitles = self.download_episode_subtitles
        open_subtitles_username = self.open_subtitles_username
        open_subtitles_password_hash = self.open_subtitles_password_hash
        is_open_subtitle_vip_account = self.is_open_subtitle_vip_account
        require_perfect_match = self.require_perfect_match

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if skip_if_embedded_subtitles_present is not UNSET:
            field_dict["SkipIfEmbeddedSubtitlesPresent"] = skip_if_embedded_subtitles_present
        if skip_if_audio_track_matches is not UNSET:
            field_dict["SkipIfAudioTrackMatches"] = skip_if_audio_track_matches
        if download_languages is not UNSET:
            field_dict["DownloadLanguages"] = download_languages
        if download_movie_subtitles is not UNSET:
            field_dict["DownloadMovieSubtitles"] = download_movie_subtitles
        if download_episode_subtitles is not UNSET:
            field_dict["DownloadEpisodeSubtitles"] = download_episode_subtitles
        if open_subtitles_username is not UNSET:
            field_dict["OpenSubtitlesUsername"] = open_subtitles_username
        if open_subtitles_password_hash is not UNSET:
            field_dict["OpenSubtitlesPasswordHash"] = open_subtitles_password_hash
        if is_open_subtitle_vip_account is not UNSET:
            field_dict["IsOpenSubtitleVipAccount"] = is_open_subtitle_vip_account
        if require_perfect_match is not UNSET:
            field_dict["RequirePerfectMatch"] = require_perfect_match

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        skip_if_embedded_subtitles_present = d.pop("SkipIfEmbeddedSubtitlesPresent", UNSET)

        skip_if_audio_track_matches = d.pop("SkipIfAudioTrackMatches", UNSET)

        download_languages = cast(List[str], d.pop("DownloadLanguages", UNSET))

        download_movie_subtitles = d.pop("DownloadMovieSubtitles", UNSET)

        download_episode_subtitles = d.pop("DownloadEpisodeSubtitles", UNSET)

        open_subtitles_username = d.pop("OpenSubtitlesUsername", UNSET)

        open_subtitles_password_hash = d.pop("OpenSubtitlesPasswordHash", UNSET)

        is_open_subtitle_vip_account = d.pop("IsOpenSubtitleVipAccount", UNSET)

        require_perfect_match = d.pop("RequirePerfectMatch", UNSET)

        subtitle_options = cls(
            skip_if_embedded_subtitles_present=skip_if_embedded_subtitles_present,
            skip_if_audio_track_matches=skip_if_audio_track_matches,
            download_languages=download_languages,
            download_movie_subtitles=download_movie_subtitles,
            download_episode_subtitles=download_episode_subtitles,
            open_subtitles_username=open_subtitles_username,
            open_subtitles_password_hash=open_subtitles_password_hash,
            is_open_subtitle_vip_account=is_open_subtitle_vip_account,
            require_perfect_match=require_perfect_match,
        )

        return subtitle_options



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="PathSubstitution")


@_attrs_define
class PathSubstitution:
    """Defines the MediaBrowser.Model.Configuration.PathSubstitution.

    Attributes:
        from_ (Union[Unset, str]): Gets or sets the value to substitute.
        to (Union[Unset, str]): Gets or sets the value to substitution with.
    """

    from_: Union[Unset, str] = UNSET
    to: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        from_ = self.from_
        to = self.to

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if from_ is not UNSET:
            field_dict["From"] = from_
        if to is not UNSET:
            field_dict["To"] = to

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        from_ = d.pop("From", UNSET)

        to = d.pop("To", UNSET)

        path_substitution = cls(
            from_=from_,
            to=to,
        )

        return path_substitution



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.session_info import SessionInfo
    from ..models.user_dto import UserDto


T = TypeVar("T", bound="AuthenticationResult")


@_attrs_define
class AuthenticationResult:
    """
    Attributes:
        user (Union[Unset, None, UserDto]): Class UserDto.
        session_info (Union[Unset, None, SessionInfo]): Class SessionInfo.
        access_token (Union[Unset, None, str]):
        server_id (Union[Unset, None, str]):
    """

    user: Union[Unset, None, "UserDto"] = UNSET
    session_info: Union[Unset, None, "SessionInfo"] = UNSET
    access_token: Union[Unset, None, str] = UNSET
    server_id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        user: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.user, Unset):
            user = self.user.to_dict() if self.user else None

        session_info: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.session_info, Unset):
            session_info = self.session_info.to_dict() if self.session_info else None

        access_token = self.access_token
        server_id = self.server_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if user is not UNSET:
            field_dict["User"] = user
        if session_info is not UNSET:
            field_dict["SessionInfo"] = session_info
        if access_token is not UNSET:
            field_dict["AccessToken"] = access_token
        if server_id is not UNSET:
            field_dict["ServerId"] = server_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.session_info import SessionInfo
        from ..models.user_dto import UserDto

        d = src_dict.copy()
        _user = d.pop("User", UNSET)
        user: Union[Unset, None, UserDto]
        if _user is None:
            user = None
        elif isinstance(_user, Unset):
            user = UNSET
        else:
            user = UserDto.from_dict(_user)

        _session_info = d.pop("SessionInfo", UNSET)
        session_info: Union[Unset, None, SessionInfo]
        if _session_info is None:
            session_info = None
        elif isinstance(_session_info, Unset):
            session_info = UNSET
        else:
            session_info = SessionInfo.from_dict(_session_info)

        access_token = d.pop("AccessToken", UNSET)

        server_id = d.pop("ServerId", UNSET)

        authentication_result = cls(
            user=user,
            session_info=session_info,
            access_token=access_token,
            server_id=server_id,
        )

        return authentication_result



from enum import Enum


class GroupUpdateType(str, Enum):
    CREATEGROUPDENIED = "CreateGroupDenied"
    GROUPDOESNOTEXIST = "GroupDoesNotExist"
    GROUPJOINED = "GroupJoined"
    GROUPLEFT = "GroupLeft"
    JOINGROUPDENIED = "JoinGroupDenied"
    LIBRARYACCESSDENIED = "LibraryAccessDenied"
    NOTINGROUP = "NotInGroup"
    PLAYQUEUE = "PlayQueue"
    STATEUPDATE = "StateUpdate"
    USERJOINED = "UserJoined"
    USERLEFT = "UserLeft"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class Video3DFormat(str, Enum):
    FULLSIDEBYSIDE = "FullSideBySide"
    FULLTOPANDBOTTOM = "FullTopAndBottom"
    HALFSIDEBYSIDE = "HalfSideBySide"
    HALFTOPANDBOTTOM = "HalfTopAndBottom"
    MVC = "MVC"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.codec_type import CodecType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.profile_condition import ProfileCondition


T = TypeVar("T", bound="CodecProfile")


@_attrs_define
class CodecProfile:
    """
    Attributes:
        type (Union[Unset, CodecType]):
        conditions (Union[Unset, None, List['ProfileCondition']]):
        apply_conditions (Union[Unset, None, List['ProfileCondition']]):
        codec (Union[Unset, None, str]):
        container (Union[Unset, None, str]):
    """

    type: Union[Unset, CodecType] = UNSET
    conditions: Union[Unset, None, List["ProfileCondition"]] = UNSET
    apply_conditions: Union[Unset, None, List["ProfileCondition"]] = UNSET
    codec: Union[Unset, None, str] = UNSET
    container: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        conditions: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.conditions, Unset):
            if self.conditions is None:
                conditions = None
            else:
                conditions = []
                for conditions_item_data in self.conditions:
                    conditions_item = conditions_item_data.to_dict()

                    conditions.append(conditions_item)

        apply_conditions: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.apply_conditions, Unset):
            if self.apply_conditions is None:
                apply_conditions = None
            else:
                apply_conditions = []
                for apply_conditions_item_data in self.apply_conditions:
                    apply_conditions_item = apply_conditions_item_data.to_dict()

                    apply_conditions.append(apply_conditions_item)

        codec = self.codec
        container = self.container

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["Type"] = type
        if conditions is not UNSET:
            field_dict["Conditions"] = conditions
        if apply_conditions is not UNSET:
            field_dict["ApplyConditions"] = apply_conditions
        if codec is not UNSET:
            field_dict["Codec"] = codec
        if container is not UNSET:
            field_dict["Container"] = container

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.profile_condition import ProfileCondition

        d = src_dict.copy()
        _type = d.pop("Type", UNSET)
        type: Union[Unset, CodecType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = CodecType(_type)

        conditions = []
        _conditions = d.pop("Conditions", UNSET)
        for conditions_item_data in _conditions or []:
            conditions_item = ProfileCondition.from_dict(conditions_item_data)

            conditions.append(conditions_item)

        apply_conditions = []
        _apply_conditions = d.pop("ApplyConditions", UNSET)
        for apply_conditions_item_data in _apply_conditions or []:
            apply_conditions_item = ProfileCondition.from_dict(apply_conditions_item_data)

            apply_conditions.append(apply_conditions_item)

        codec = d.pop("Codec", UNSET)

        container = d.pop("Container", UNSET)

        codec_profile = cls(
            type=type,
            conditions=conditions,
            apply_conditions=apply_conditions,
            codec=codec,
            container=container,
        )

        return codec_profile



from enum import Enum


class SubtitlePlaybackMode(str, Enum):
    ALWAYS = "Always"
    DEFAULT = "Default"
    NONE = "None"
    ONLYFORCED = "OnlyForced"
    SMART = "Smart"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.task_state import TaskState
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.task_result import TaskResult
    from ..models.task_trigger_info import TaskTriggerInfo


T = TypeVar("T", bound="TaskInfo")


@_attrs_define
class TaskInfo:
    """Class TaskInfo.

    Attributes:
        name (Union[Unset, None, str]): Gets or sets the name.
        state (Union[Unset, TaskState]): Enum TaskState.
        current_progress_percentage (Union[Unset, None, float]): Gets or sets the progress.
        id (Union[Unset, None, str]): Gets or sets the id.
        last_execution_result (Union[Unset, None, TaskResult]): Class TaskExecutionInfo.
        triggers (Union[Unset, None, List['TaskTriggerInfo']]): Gets or sets the triggers.
        description (Union[Unset, None, str]): Gets or sets the description.
        category (Union[Unset, None, str]): Gets or sets the category.
        is_hidden (Union[Unset, bool]): Gets or sets a value indicating whether this instance is hidden.
        key (Union[Unset, None, str]): Gets or sets the key.
    """

    name: Union[Unset, None, str] = UNSET
    state: Union[Unset, TaskState] = UNSET
    current_progress_percentage: Union[Unset, None, float] = UNSET
    id: Union[Unset, None, str] = UNSET
    last_execution_result: Union[Unset, None, "TaskResult"] = UNSET
    triggers: Union[Unset, None, List["TaskTriggerInfo"]] = UNSET
    description: Union[Unset, None, str] = UNSET
    category: Union[Unset, None, str] = UNSET
    is_hidden: Union[Unset, bool] = UNSET
    key: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        state: Union[Unset, str] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.value

        current_progress_percentage = self.current_progress_percentage
        id = self.id
        last_execution_result: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.last_execution_result, Unset):
            last_execution_result = self.last_execution_result.to_dict() if self.last_execution_result else None

        triggers: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.triggers, Unset):
            if self.triggers is None:
                triggers = None
            else:
                triggers = []
                for triggers_item_data in self.triggers:
                    triggers_item = triggers_item_data.to_dict()

                    triggers.append(triggers_item)

        description = self.description
        category = self.category
        is_hidden = self.is_hidden
        key = self.key

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if state is not UNSET:
            field_dict["State"] = state
        if current_progress_percentage is not UNSET:
            field_dict["CurrentProgressPercentage"] = current_progress_percentage
        if id is not UNSET:
            field_dict["Id"] = id
        if last_execution_result is not UNSET:
            field_dict["LastExecutionResult"] = last_execution_result
        if triggers is not UNSET:
            field_dict["Triggers"] = triggers
        if description is not UNSET:
            field_dict["Description"] = description
        if category is not UNSET:
            field_dict["Category"] = category
        if is_hidden is not UNSET:
            field_dict["IsHidden"] = is_hidden
        if key is not UNSET:
            field_dict["Key"] = key

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.task_result import TaskResult
        from ..models.task_trigger_info import TaskTriggerInfo

        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        _state = d.pop("State", UNSET)
        state: Union[Unset, TaskState]
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = TaskState(_state)

        current_progress_percentage = d.pop("CurrentProgressPercentage", UNSET)

        id = d.pop("Id", UNSET)

        _last_execution_result = d.pop("LastExecutionResult", UNSET)
        last_execution_result: Union[Unset, None, TaskResult]
        if _last_execution_result is None:
            last_execution_result = None
        elif isinstance(_last_execution_result, Unset):
            last_execution_result = UNSET
        else:
            last_execution_result = TaskResult.from_dict(_last_execution_result)

        triggers = []
        _triggers = d.pop("Triggers", UNSET)
        for triggers_item_data in _triggers or []:
            triggers_item = TaskTriggerInfo.from_dict(triggers_item_data)

            triggers.append(triggers_item)

        description = d.pop("Description", UNSET)

        category = d.pop("Category", UNSET)

        is_hidden = d.pop("IsHidden", UNSET)

        key = d.pop("Key", UNSET)

        task_info = cls(
            name=name,
            state=state,
            current_progress_percentage=current_progress_percentage,
            id=id,
            last_execution_result=last_execution_result,
            triggers=triggers,
            description=description,
            category=category,
            is_hidden=is_hidden,
            key=key,
        )

        return task_info



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.country_info import CountryInfo
    from ..models.culture_dto import CultureDto
    from ..models.external_id_info import ExternalIdInfo
    from ..models.name_value_pair import NameValuePair
    from ..models.parental_rating import ParentalRating


T = TypeVar("T", bound="MetadataEditorInfo")


@_attrs_define
class MetadataEditorInfo:
    """
    Attributes:
        parental_rating_options (Union[Unset, List['ParentalRating']]):
        countries (Union[Unset, List['CountryInfo']]):
        cultures (Union[Unset, List['CultureDto']]):
        external_id_infos (Union[Unset, List['ExternalIdInfo']]):
        content_type (Union[Unset, None, str]):
        content_type_options (Union[Unset, List['NameValuePair']]):
    """

    parental_rating_options: Union[Unset, List["ParentalRating"]] = UNSET
    countries: Union[Unset, List["CountryInfo"]] = UNSET
    cultures: Union[Unset, List["CultureDto"]] = UNSET
    external_id_infos: Union[Unset, List["ExternalIdInfo"]] = UNSET
    content_type: Union[Unset, None, str] = UNSET
    content_type_options: Union[Unset, List["NameValuePair"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        parental_rating_options: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.parental_rating_options, Unset):
            parental_rating_options = []
            for parental_rating_options_item_data in self.parental_rating_options:
                parental_rating_options_item = parental_rating_options_item_data.to_dict()

                parental_rating_options.append(parental_rating_options_item)

        countries: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.countries, Unset):
            countries = []
            for countries_item_data in self.countries:
                countries_item = countries_item_data.to_dict()

                countries.append(countries_item)

        cultures: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.cultures, Unset):
            cultures = []
            for cultures_item_data in self.cultures:
                cultures_item = cultures_item_data.to_dict()

                cultures.append(cultures_item)

        external_id_infos: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.external_id_infos, Unset):
            external_id_infos = []
            for external_id_infos_item_data in self.external_id_infos:
                external_id_infos_item = external_id_infos_item_data.to_dict()

                external_id_infos.append(external_id_infos_item)

        content_type = self.content_type
        content_type_options: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.content_type_options, Unset):
            content_type_options = []
            for content_type_options_item_data in self.content_type_options:
                content_type_options_item = content_type_options_item_data.to_dict()

                content_type_options.append(content_type_options_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if parental_rating_options is not UNSET:
            field_dict["ParentalRatingOptions"] = parental_rating_options
        if countries is not UNSET:
            field_dict["Countries"] = countries
        if cultures is not UNSET:
            field_dict["Cultures"] = cultures
        if external_id_infos is not UNSET:
            field_dict["ExternalIdInfos"] = external_id_infos
        if content_type is not UNSET:
            field_dict["ContentType"] = content_type
        if content_type_options is not UNSET:
            field_dict["ContentTypeOptions"] = content_type_options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.country_info import CountryInfo
        from ..models.culture_dto import CultureDto
        from ..models.external_id_info import ExternalIdInfo
        from ..models.name_value_pair import NameValuePair
        from ..models.parental_rating import ParentalRating

        d = src_dict.copy()
        parental_rating_options = []
        _parental_rating_options = d.pop("ParentalRatingOptions", UNSET)
        for parental_rating_options_item_data in _parental_rating_options or []:
            parental_rating_options_item = ParentalRating.from_dict(parental_rating_options_item_data)

            parental_rating_options.append(parental_rating_options_item)

        countries = []
        _countries = d.pop("Countries", UNSET)
        for countries_item_data in _countries or []:
            countries_item = CountryInfo.from_dict(countries_item_data)

            countries.append(countries_item)

        cultures = []
        _cultures = d.pop("Cultures", UNSET)
        for cultures_item_data in _cultures or []:
            cultures_item = CultureDto.from_dict(cultures_item_data)

            cultures.append(cultures_item)

        external_id_infos = []
        _external_id_infos = d.pop("ExternalIdInfos", UNSET)
        for external_id_infos_item_data in _external_id_infos or []:
            external_id_infos_item = ExternalIdInfo.from_dict(external_id_infos_item_data)

            external_id_infos.append(external_id_infos_item)

        content_type = d.pop("ContentType", UNSET)

        content_type_options = []
        _content_type_options = d.pop("ContentTypeOptions", UNSET)
        for content_type_options_item_data in _content_type_options or []:
            content_type_options_item = NameValuePair.from_dict(content_type_options_item_data)

            content_type_options.append(content_type_options_item)

        metadata_editor_info = cls(
            parental_rating_options=parental_rating_options,
            countries=countries,
            cultures=cultures,
            external_id_infos=external_id_infos,
            content_type=content_type,
            content_type_options=content_type_options,
        )

        return metadata_editor_info



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.base_item_person_image_blur_hashes import BaseItemPersonImageBlurHashes


T = TypeVar("T", bound="BaseItemPerson")


@_attrs_define
class BaseItemPerson:
    """This is used by the api to get information about a Person within a BaseItem.

    Attributes:
        name (Union[Unset, None, str]): Gets or sets the name.
        id (Union[Unset, str]): Gets or sets the identifier.
        role (Union[Unset, None, str]): Gets or sets the role.
        type (Union[Unset, None, str]): Gets or sets the type.
        primary_image_tag (Union[Unset, None, str]): Gets or sets the primary image tag.
        image_blur_hashes (Union[Unset, None, BaseItemPersonImageBlurHashes]): Gets or sets the primary image blurhash.
    """

    name: Union[Unset, None, str] = UNSET
    id: Union[Unset, str] = UNSET
    role: Union[Unset, None, str] = UNSET
    type: Union[Unset, None, str] = UNSET
    primary_image_tag: Union[Unset, None, str] = UNSET
    image_blur_hashes: Union[Unset, None, "BaseItemPersonImageBlurHashes"] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        id = self.id
        role = self.role
        type = self.type
        primary_image_tag = self.primary_image_tag
        image_blur_hashes: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.image_blur_hashes, Unset):
            image_blur_hashes = self.image_blur_hashes.to_dict() if self.image_blur_hashes else None

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if id is not UNSET:
            field_dict["Id"] = id
        if role is not UNSET:
            field_dict["Role"] = role
        if type is not UNSET:
            field_dict["Type"] = type
        if primary_image_tag is not UNSET:
            field_dict["PrimaryImageTag"] = primary_image_tag
        if image_blur_hashes is not UNSET:
            field_dict["ImageBlurHashes"] = image_blur_hashes

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.base_item_person_image_blur_hashes import BaseItemPersonImageBlurHashes

        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        id = d.pop("Id", UNSET)

        role = d.pop("Role", UNSET)

        type = d.pop("Type", UNSET)

        primary_image_tag = d.pop("PrimaryImageTag", UNSET)

        _image_blur_hashes = d.pop("ImageBlurHashes", UNSET)
        image_blur_hashes: Union[Unset, None, BaseItemPersonImageBlurHashes]
        if _image_blur_hashes is None:
            image_blur_hashes = None
        elif isinstance(_image_blur_hashes, Unset):
            image_blur_hashes = UNSET
        else:
            image_blur_hashes = BaseItemPersonImageBlurHashes.from_dict(_image_blur_hashes)

        base_item_person = cls(
            name=name,
            id=id,
            role=role,
            type=type,
            primary_image_tag=primary_image_tag,
            image_blur_hashes=image_blur_hashes,
        )

        return base_item_person



from typing import Any, Dict, Type, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="UploadSubtitleDto")


@_attrs_define
class UploadSubtitleDto:
    """Upload subtitles dto.

    Attributes:
        language (str): Gets or sets the subtitle language.
        format_ (str): Gets or sets the subtitle format.
        is_forced (bool): Gets or sets a value indicating whether the subtitle is forced.
        data (str): Gets or sets the subtitle data.
    """

    language: str
    format_: str
    is_forced: bool
    data: str

    def to_dict(self) -> Dict[str, Any]:
        language = self.language
        format_ = self.format_
        is_forced = self.is_forced
        data = self.data

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "Language": language,
                "Format": format_,
                "IsForced": is_forced,
                "Data": data,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        language = d.pop("Language")

        format_ = d.pop("Format")

        is_forced = d.pop("IsForced")

        data = d.pop("Data")

        upload_subtitle_dto = cls(
            language=language,
            format_=format_,
            is_forced=is_forced,
            data=data,
        )

        return upload_subtitle_dto



from enum import Enum


class FileSystemEntryType(str, Enum):
    DIRECTORY = "Directory"
    FILE = "File"
    NETWORKCOMPUTER = "NetworkComputer"
    NETWORKSHARE = "NetworkShare"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.user_configuration import UserConfiguration
    from ..models.user_policy import UserPolicy


T = TypeVar("T", bound="UserDto")


@_attrs_define
class UserDto:
    """Class UserDto.

    Attributes:
        name (Union[Unset, None, str]): Gets or sets the name.
        server_id (Union[Unset, None, str]): Gets or sets the server identifier.
        server_name (Union[Unset, None, str]): Gets or sets the name of the server.
            This is not used by the server and is for client-side usage only.
        id (Union[Unset, str]): Gets or sets the id.
        primary_image_tag (Union[Unset, None, str]): Gets or sets the primary image tag.
        has_password (Union[Unset, bool]): Gets or sets a value indicating whether this instance has password.
        has_configured_password (Union[Unset, bool]): Gets or sets a value indicating whether this instance has
            configured password.
        has_configured_easy_password (Union[Unset, bool]): Gets or sets a value indicating whether this instance has
            configured easy password.
        enable_auto_login (Union[Unset, None, bool]): Gets or sets whether async login is enabled or not.
        last_login_date (Union[Unset, None, datetime.datetime]): Gets or sets the last login date.
        last_activity_date (Union[Unset, None, datetime.datetime]): Gets or sets the last activity date.
        configuration (Union[Unset, None, UserConfiguration]): Class UserConfiguration.
        policy (Union[Unset, None, UserPolicy]):
        primary_image_aspect_ratio (Union[Unset, None, float]): Gets or sets the primary image aspect ratio.
    """

    name: Union[Unset, None, str] = UNSET
    server_id: Union[Unset, None, str] = UNSET
    server_name: Union[Unset, None, str] = UNSET
    id: Union[Unset, str] = UNSET
    primary_image_tag: Union[Unset, None, str] = UNSET
    has_password: Union[Unset, bool] = UNSET
    has_configured_password: Union[Unset, bool] = UNSET
    has_configured_easy_password: Union[Unset, bool] = UNSET
    enable_auto_login: Union[Unset, None, bool] = UNSET
    last_login_date: Union[Unset, None, datetime.datetime] = UNSET
    last_activity_date: Union[Unset, None, datetime.datetime] = UNSET
    configuration: Union[Unset, None, "UserConfiguration"] = UNSET
    policy: Union[Unset, None, "UserPolicy"] = UNSET
    primary_image_aspect_ratio: Union[Unset, None, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        server_id = self.server_id
        server_name = self.server_name
        id = self.id
        primary_image_tag = self.primary_image_tag
        has_password = self.has_password
        has_configured_password = self.has_configured_password
        has_configured_easy_password = self.has_configured_easy_password
        enable_auto_login = self.enable_auto_login
        last_login_date: Union[Unset, None, str] = UNSET
        if not isinstance(self.last_login_date, Unset):
            last_login_date = self.last_login_date.isoformat() if self.last_login_date else None

        last_activity_date: Union[Unset, None, str] = UNSET
        if not isinstance(self.last_activity_date, Unset):
            last_activity_date = self.last_activity_date.isoformat() if self.last_activity_date else None

        configuration: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.configuration, Unset):
            configuration = self.configuration.to_dict() if self.configuration else None

        policy: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.policy, Unset):
            policy = self.policy.to_dict() if self.policy else None

        primary_image_aspect_ratio = self.primary_image_aspect_ratio

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if server_id is not UNSET:
            field_dict["ServerId"] = server_id
        if server_name is not UNSET:
            field_dict["ServerName"] = server_name
        if id is not UNSET:
            field_dict["Id"] = id
        if primary_image_tag is not UNSET:
            field_dict["PrimaryImageTag"] = primary_image_tag
        if has_password is not UNSET:
            field_dict["HasPassword"] = has_password
        if has_configured_password is not UNSET:
            field_dict["HasConfiguredPassword"] = has_configured_password
        if has_configured_easy_password is not UNSET:
            field_dict["HasConfiguredEasyPassword"] = has_configured_easy_password
        if enable_auto_login is not UNSET:
            field_dict["EnableAutoLogin"] = enable_auto_login
        if last_login_date is not UNSET:
            field_dict["LastLoginDate"] = last_login_date
        if last_activity_date is not UNSET:
            field_dict["LastActivityDate"] = last_activity_date
        if configuration is not UNSET:
            field_dict["Configuration"] = configuration
        if policy is not UNSET:
            field_dict["Policy"] = policy
        if primary_image_aspect_ratio is not UNSET:
            field_dict["PrimaryImageAspectRatio"] = primary_image_aspect_ratio

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.user_configuration import UserConfiguration
        from ..models.user_policy import UserPolicy

        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        server_id = d.pop("ServerId", UNSET)

        server_name = d.pop("ServerName", UNSET)

        id = d.pop("Id", UNSET)

        primary_image_tag = d.pop("PrimaryImageTag", UNSET)

        has_password = d.pop("HasPassword", UNSET)

        has_configured_password = d.pop("HasConfiguredPassword", UNSET)

        has_configured_easy_password = d.pop("HasConfiguredEasyPassword", UNSET)

        enable_auto_login = d.pop("EnableAutoLogin", UNSET)

        _last_login_date = d.pop("LastLoginDate", UNSET)
        last_login_date: Union[Unset, None, datetime.datetime]
        if _last_login_date is None:
            last_login_date = None
        elif isinstance(_last_login_date, Unset):
            last_login_date = UNSET
        else:
            last_login_date = isoparse(_last_login_date)

        _last_activity_date = d.pop("LastActivityDate", UNSET)
        last_activity_date: Union[Unset, None, datetime.datetime]
        if _last_activity_date is None:
            last_activity_date = None
        elif isinstance(_last_activity_date, Unset):
            last_activity_date = UNSET
        else:
            last_activity_date = isoparse(_last_activity_date)

        _configuration = d.pop("Configuration", UNSET)
        configuration: Union[Unset, None, UserConfiguration]
        if _configuration is None:
            configuration = None
        elif isinstance(_configuration, Unset):
            configuration = UNSET
        else:
            configuration = UserConfiguration.from_dict(_configuration)

        _policy = d.pop("Policy", UNSET)
        policy: Union[Unset, None, UserPolicy]
        if _policy is None:
            policy = None
        elif isinstance(_policy, Unset):
            policy = UNSET
        else:
            policy = UserPolicy.from_dict(_policy)

        primary_image_aspect_ratio = d.pop("PrimaryImageAspectRatio", UNSET)

        user_dto = cls(
            name=name,
            server_id=server_id,
            server_name=server_name,
            id=id,
            primary_image_tag=primary_image_tag,
            has_password=has_password,
            has_configured_password=has_configured_password,
            has_configured_easy_password=has_configured_easy_password,
            enable_auto_login=enable_auto_login,
            last_login_date=last_login_date,
            last_activity_date=last_activity_date,
            configuration=configuration,
            policy=policy,
            primary_image_aspect_ratio=primary_image_aspect_ratio,
        )

        return user_dto



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.library_option_info_dto import LibraryOptionInfoDto
    from ..models.library_type_options_dto import LibraryTypeOptionsDto


T = TypeVar("T", bound="LibraryOptionsResultDto")


@_attrs_define
class LibraryOptionsResultDto:
    """Library options result dto.

    Attributes:
        metadata_savers (Union[Unset, List['LibraryOptionInfoDto']]): Gets or sets the metadata savers.
        metadata_readers (Union[Unset, List['LibraryOptionInfoDto']]): Gets or sets the metadata readers.
        subtitle_fetchers (Union[Unset, List['LibraryOptionInfoDto']]): Gets or sets the subtitle fetchers.
        type_options (Union[Unset, List['LibraryTypeOptionsDto']]): Gets or sets the type options.
    """

    metadata_savers: Union[Unset, List["LibraryOptionInfoDto"]] = UNSET
    metadata_readers: Union[Unset, List["LibraryOptionInfoDto"]] = UNSET
    subtitle_fetchers: Union[Unset, List["LibraryOptionInfoDto"]] = UNSET
    type_options: Union[Unset, List["LibraryTypeOptionsDto"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        metadata_savers: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.metadata_savers, Unset):
            metadata_savers = []
            for metadata_savers_item_data in self.metadata_savers:
                metadata_savers_item = metadata_savers_item_data.to_dict()

                metadata_savers.append(metadata_savers_item)

        metadata_readers: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.metadata_readers, Unset):
            metadata_readers = []
            for metadata_readers_item_data in self.metadata_readers:
                metadata_readers_item = metadata_readers_item_data.to_dict()

                metadata_readers.append(metadata_readers_item)

        subtitle_fetchers: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.subtitle_fetchers, Unset):
            subtitle_fetchers = []
            for subtitle_fetchers_item_data in self.subtitle_fetchers:
                subtitle_fetchers_item = subtitle_fetchers_item_data.to_dict()

                subtitle_fetchers.append(subtitle_fetchers_item)

        type_options: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.type_options, Unset):
            type_options = []
            for type_options_item_data in self.type_options:
                type_options_item = type_options_item_data.to_dict()

                type_options.append(type_options_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if metadata_savers is not UNSET:
            field_dict["MetadataSavers"] = metadata_savers
        if metadata_readers is not UNSET:
            field_dict["MetadataReaders"] = metadata_readers
        if subtitle_fetchers is not UNSET:
            field_dict["SubtitleFetchers"] = subtitle_fetchers
        if type_options is not UNSET:
            field_dict["TypeOptions"] = type_options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.library_option_info_dto import LibraryOptionInfoDto
        from ..models.library_type_options_dto import LibraryTypeOptionsDto

        d = src_dict.copy()
        metadata_savers = []
        _metadata_savers = d.pop("MetadataSavers", UNSET)
        for metadata_savers_item_data in _metadata_savers or []:
            metadata_savers_item = LibraryOptionInfoDto.from_dict(metadata_savers_item_data)

            metadata_savers.append(metadata_savers_item)

        metadata_readers = []
        _metadata_readers = d.pop("MetadataReaders", UNSET)
        for metadata_readers_item_data in _metadata_readers or []:
            metadata_readers_item = LibraryOptionInfoDto.from_dict(metadata_readers_item_data)

            metadata_readers.append(metadata_readers_item)

        subtitle_fetchers = []
        _subtitle_fetchers = d.pop("SubtitleFetchers", UNSET)
        for subtitle_fetchers_item_data in _subtitle_fetchers or []:
            subtitle_fetchers_item = LibraryOptionInfoDto.from_dict(subtitle_fetchers_item_data)

            subtitle_fetchers.append(subtitle_fetchers_item)

        type_options = []
        _type_options = d.pop("TypeOptions", UNSET)
        for type_options_item_data in _type_options or []:
            type_options_item = LibraryTypeOptionsDto.from_dict(type_options_item_data)

            type_options.append(type_options_item)

        library_options_result_dto = cls(
            metadata_savers=metadata_savers,
            metadata_readers=metadata_readers,
            subtitle_fetchers=subtitle_fetchers,
            type_options=type_options,
        )

        return library_options_result_dto



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.notification_level import NotificationLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationDto")


@_attrs_define
class NotificationDto:
    """The notification DTO.

    Attributes:
        id (Union[Unset, str]): Gets or sets the notification ID. Defaults to an empty string.
        user_id (Union[Unset, str]): Gets or sets the notification's user ID. Defaults to an empty string.
        date (Union[Unset, datetime.datetime]): Gets or sets the notification date.
        is_read (Union[Unset, bool]): Gets or sets a value indicating whether the notification has been read. Defaults
            to false.
        name (Union[Unset, str]): Gets or sets the notification's name. Defaults to an empty string.
        description (Union[Unset, str]): Gets or sets the notification's description. Defaults to an empty string.
        url (Union[Unset, str]): Gets or sets the notification's URL. Defaults to an empty string.
        level (Union[Unset, NotificationLevel]):
    """

    id: Union[Unset, str] = UNSET
    user_id: Union[Unset, str] = UNSET
    date: Union[Unset, datetime.datetime] = UNSET
    is_read: Union[Unset, bool] = UNSET
    name: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    url: Union[Unset, str] = UNSET
    level: Union[Unset, NotificationLevel] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        user_id = self.user_id
        date: Union[Unset, str] = UNSET
        if not isinstance(self.date, Unset):
            date = self.date.isoformat()

        is_read = self.is_read
        name = self.name
        description = self.description
        url = self.url
        level: Union[Unset, str] = UNSET
        if not isinstance(self.level, Unset):
            level = self.level.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if user_id is not UNSET:
            field_dict["UserId"] = user_id
        if date is not UNSET:
            field_dict["Date"] = date
        if is_read is not UNSET:
            field_dict["IsRead"] = is_read
        if name is not UNSET:
            field_dict["Name"] = name
        if description is not UNSET:
            field_dict["Description"] = description
        if url is not UNSET:
            field_dict["Url"] = url
        if level is not UNSET:
            field_dict["Level"] = level

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        user_id = d.pop("UserId", UNSET)

        _date = d.pop("Date", UNSET)
        date: Union[Unset, datetime.datetime]
        if isinstance(_date, Unset):
            date = UNSET
        else:
            date = isoparse(_date)

        is_read = d.pop("IsRead", UNSET)

        name = d.pop("Name", UNSET)

        description = d.pop("Description", UNSET)

        url = d.pop("Url", UNSET)

        _level = d.pop("Level", UNSET)
        level: Union[Unset, NotificationLevel]
        if isinstance(_level, Unset):
            level = UNSET
        else:
            level = NotificationLevel(_level)

        notification_dto = cls(
            id=id,
            user_id=user_id,
            date=date,
            is_read=is_read,
            name=name,
            description=description,
            url=url,
            level=level,
        )

        return notification_dto



from enum import Enum


class MetadataField(str, Enum):
    CAST = "Cast"
    GENRES = "Genres"
    NAME = "Name"
    OFFICIALRATING = "OfficialRating"
    OVERVIEW = "Overview"
    PRODUCTIONLOCATIONS = "ProductionLocations"
    RUNTIME = "Runtime"
    STUDIOS = "Studios"
    TAGS = "Tags"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="AuthenticateUserByName")


@_attrs_define
class AuthenticateUserByName:
    """The authenticate user by name request body.

    Attributes:
        username (Union[Unset, None, str]): Gets or sets the username.
        pw (Union[Unset, None, str]): Gets or sets the plain text password.
        password (Union[Unset, None, str]): Gets or sets the sha1-hashed password.
    """

    username: Union[Unset, None, str] = UNSET
    pw: Union[Unset, None, str] = UNSET
    password: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        username = self.username
        pw = self.pw
        password = self.password

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if username is not UNSET:
            field_dict["Username"] = username
        if pw is not UNSET:
            field_dict["Pw"] = pw
        if password is not UNSET:
            field_dict["Password"] = password

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        username = d.pop("Username", UNSET)

        pw = d.pop("Pw", UNSET)

        password = d.pop("Password", UNSET)

        authenticate_user_by_name = cls(
            username=username,
            pw=pw,
            password=password,
        )

        return authenticate_user_by_name



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.group_repeat_mode import GroupRepeatMode
from ..types import UNSET, Unset

T = TypeVar("T", bound="SetRepeatModeRequestDto")


@_attrs_define
class SetRepeatModeRequestDto:
    """Class SetRepeatModeRequestDto.

    Attributes:
        mode (Union[Unset, GroupRepeatMode]): Enum GroupRepeatMode.
    """

    mode: Union[Unset, GroupRepeatMode] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        mode: Union[Unset, str] = UNSET
        if not isinstance(self.mode, Unset):
            mode = self.mode.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if mode is not UNSET:
            field_dict["Mode"] = mode

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _mode = d.pop("Mode", UNSET)
        mode: Union[Unset, GroupRepeatMode]
        if isinstance(_mode, Unset):
            mode = UNSET
        else:
            mode = GroupRepeatMode(_mode)

        set_repeat_mode_request_dto = cls(
            mode=mode,
        )

        return set_repeat_mode_request_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.day_of_week import DayOfWeek
from ..types import UNSET, Unset

T = TypeVar("T", bound="TaskTriggerInfo")


@_attrs_define
class TaskTriggerInfo:
    """Class TaskTriggerInfo.

    Attributes:
        type (Union[Unset, None, str]): Gets or sets the type.
        time_of_day_ticks (Union[Unset, None, int]): Gets or sets the time of day.
        interval_ticks (Union[Unset, None, int]): Gets or sets the interval.
        day_of_week (Union[Unset, None, DayOfWeek]):
        max_runtime_ticks (Union[Unset, None, int]): Gets or sets the maximum runtime ticks.
    """

    type: Union[Unset, None, str] = UNSET
    time_of_day_ticks: Union[Unset, None, int] = UNSET
    interval_ticks: Union[Unset, None, int] = UNSET
    day_of_week: Union[Unset, None, DayOfWeek] = UNSET
    max_runtime_ticks: Union[Unset, None, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        time_of_day_ticks = self.time_of_day_ticks
        interval_ticks = self.interval_ticks
        day_of_week: Union[Unset, None, str] = UNSET
        if not isinstance(self.day_of_week, Unset):
            day_of_week = self.day_of_week.value if self.day_of_week else None

        max_runtime_ticks = self.max_runtime_ticks

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["Type"] = type
        if time_of_day_ticks is not UNSET:
            field_dict["TimeOfDayTicks"] = time_of_day_ticks
        if interval_ticks is not UNSET:
            field_dict["IntervalTicks"] = interval_ticks
        if day_of_week is not UNSET:
            field_dict["DayOfWeek"] = day_of_week
        if max_runtime_ticks is not UNSET:
            field_dict["MaxRuntimeTicks"] = max_runtime_ticks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = d.pop("Type", UNSET)

        time_of_day_ticks = d.pop("TimeOfDayTicks", UNSET)

        interval_ticks = d.pop("IntervalTicks", UNSET)

        _day_of_week = d.pop("DayOfWeek", UNSET)
        day_of_week: Union[Unset, None, DayOfWeek]
        if _day_of_week is None:
            day_of_week = None
        elif isinstance(_day_of_week, Unset):
            day_of_week = UNSET
        else:
            day_of_week = DayOfWeek(_day_of_week)

        max_runtime_ticks = d.pop("MaxRuntimeTicks", UNSET)

        task_trigger_info = cls(
            type=type,
            time_of_day_ticks=time_of_day_ticks,
            interval_ticks=interval_ticks,
            day_of_week=day_of_week,
            max_runtime_ticks=max_runtime_ticks,
        )

        return task_trigger_info



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.create_playlist_dto import CreatePlaylistDto
from ...models.playlist_creation_result import PlaylistCreationResult
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    json_body: CreatePlaylistDto,
    name: Union[Unset, None, str] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    media_type: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["name"] = name

    json_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(ids, Unset):
        if ids is None:
            json_ids = None
        else:
            json_ids = ids

    params["ids"] = json_ids

    params["userId"] = user_id

    params["mediaType"] = media_type

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/Playlists",
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, PlaylistCreationResult]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = PlaylistCreationResult.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, PlaylistCreationResult]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: CreatePlaylistDto,
    name: Union[Unset, None, str] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    media_type: Union[Unset, None, str] = UNSET,
) -> Response[Union[Any, PlaylistCreationResult]]:
    """Creates a new playlist.

     For backwards compatibility parameters can be sent via Query or Body, with Query having higher
    precedence.
    Query parameters are obsolete.

    Args:
        name (Union[Unset, None, str]):
        ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        media_type (Union[Unset, None, str]):
        json_body (CreatePlaylistDto): Create new playlist dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, PlaylistCreationResult]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        name=name,
        ids=ids,
        user_id=user_id,
        media_type=media_type,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: CreatePlaylistDto,
    name: Union[Unset, None, str] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    media_type: Union[Unset, None, str] = UNSET,
) -> Optional[Union[Any, PlaylistCreationResult]]:
    """Creates a new playlist.

     For backwards compatibility parameters can be sent via Query or Body, with Query having higher
    precedence.
    Query parameters are obsolete.

    Args:
        name (Union[Unset, None, str]):
        ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        media_type (Union[Unset, None, str]):
        json_body (CreatePlaylistDto): Create new playlist dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, PlaylistCreationResult]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        name=name,
        ids=ids,
        user_id=user_id,
        media_type=media_type,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: CreatePlaylistDto,
    name: Union[Unset, None, str] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    media_type: Union[Unset, None, str] = UNSET,
) -> Response[Union[Any, PlaylistCreationResult]]:
    """Creates a new playlist.

     For backwards compatibility parameters can be sent via Query or Body, with Query having higher
    precedence.
    Query parameters are obsolete.

    Args:
        name (Union[Unset, None, str]):
        ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        media_type (Union[Unset, None, str]):
        json_body (CreatePlaylistDto): Create new playlist dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, PlaylistCreationResult]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        name=name,
        ids=ids,
        user_id=user_id,
        media_type=media_type,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: CreatePlaylistDto,
    name: Union[Unset, None, str] = UNSET,
    ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    media_type: Union[Unset, None, str] = UNSET,
) -> Optional[Union[Any, PlaylistCreationResult]]:
    """Creates a new playlist.

     For backwards compatibility parameters can be sent via Query or Body, with Query having higher
    precedence.
    Query parameters are obsolete.

    Args:
        name (Union[Unset, None, str]):
        ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        media_type (Union[Unset, None, str]):
        json_body (CreatePlaylistDto): Create new playlist dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, PlaylistCreationResult]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            name=name,
            ids=ids,
            user_id=user_id,
            media_type=media_type,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ConfigImageTypes")


@_attrs_define
class ConfigImageTypes:
    """
    Attributes:
        backdrop_sizes (Union[Unset, None, List[str]]):
        base_url (Union[Unset, None, str]):
        logo_sizes (Union[Unset, None, List[str]]):
        poster_sizes (Union[Unset, None, List[str]]):
        profile_sizes (Union[Unset, None, List[str]]):
        secure_base_url (Union[Unset, None, str]):
        still_sizes (Union[Unset, None, List[str]]):
    """

    backdrop_sizes: Union[Unset, None, List[str]] = UNSET
    base_url: Union[Unset, None, str] = UNSET
    logo_sizes: Union[Unset, None, List[str]] = UNSET
    poster_sizes: Union[Unset, None, List[str]] = UNSET
    profile_sizes: Union[Unset, None, List[str]] = UNSET
    secure_base_url: Union[Unset, None, str] = UNSET
    still_sizes: Union[Unset, None, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        backdrop_sizes: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.backdrop_sizes, Unset):
            if self.backdrop_sizes is None:
                backdrop_sizes = None
            else:
                backdrop_sizes = self.backdrop_sizes

        base_url = self.base_url
        logo_sizes: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.logo_sizes, Unset):
            if self.logo_sizes is None:
                logo_sizes = None
            else:
                logo_sizes = self.logo_sizes

        poster_sizes: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.poster_sizes, Unset):
            if self.poster_sizes is None:
                poster_sizes = None
            else:
                poster_sizes = self.poster_sizes

        profile_sizes: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.profile_sizes, Unset):
            if self.profile_sizes is None:
                profile_sizes = None
            else:
                profile_sizes = self.profile_sizes

        secure_base_url = self.secure_base_url
        still_sizes: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.still_sizes, Unset):
            if self.still_sizes is None:
                still_sizes = None
            else:
                still_sizes = self.still_sizes

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if backdrop_sizes is not UNSET:
            field_dict["BackdropSizes"] = backdrop_sizes
        if base_url is not UNSET:
            field_dict["BaseUrl"] = base_url
        if logo_sizes is not UNSET:
            field_dict["LogoSizes"] = logo_sizes
        if poster_sizes is not UNSET:
            field_dict["PosterSizes"] = poster_sizes
        if profile_sizes is not UNSET:
            field_dict["ProfileSizes"] = profile_sizes
        if secure_base_url is not UNSET:
            field_dict["SecureBaseUrl"] = secure_base_url
        if still_sizes is not UNSET:
            field_dict["StillSizes"] = still_sizes

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        backdrop_sizes = cast(List[str], d.pop("BackdropSizes", UNSET))

        base_url = d.pop("BaseUrl", UNSET)

        logo_sizes = cast(List[str], d.pop("LogoSizes", UNSET))

        poster_sizes = cast(List[str], d.pop("PosterSizes", UNSET))

        profile_sizes = cast(List[str], d.pop("ProfileSizes", UNSET))

        secure_base_url = d.pop("SecureBaseUrl", UNSET)

        still_sizes = cast(List[str], d.pop("StillSizes", UNSET))

        config_image_types = cls(
            backdrop_sizes=backdrop_sizes,
            base_url=base_url,
            logo_sizes=logo_sizes,
            poster_sizes=poster_sizes,
            profile_sizes=profile_sizes,
            secure_base_url=secure_base_url,
            still_sizes=still_sizes,
        )

        return config_image_types



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.forgot_password_action import ForgotPasswordAction
from ..types import UNSET, Unset

T = TypeVar("T", bound="ForgotPasswordResult")


@_attrs_define
class ForgotPasswordResult:
    """
    Attributes:
        action (Union[Unset, ForgotPasswordAction]):
        pin_file (Union[Unset, None, str]): Gets or sets the pin file.
        pin_expiration_date (Union[Unset, None, datetime.datetime]): Gets or sets the pin expiration date.
    """

    action: Union[Unset, ForgotPasswordAction] = UNSET
    pin_file: Union[Unset, None, str] = UNSET
    pin_expiration_date: Union[Unset, None, datetime.datetime] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        action: Union[Unset, str] = UNSET
        if not isinstance(self.action, Unset):
            action = self.action.value

        pin_file = self.pin_file
        pin_expiration_date: Union[Unset, None, str] = UNSET
        if not isinstance(self.pin_expiration_date, Unset):
            pin_expiration_date = self.pin_expiration_date.isoformat() if self.pin_expiration_date else None

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if action is not UNSET:
            field_dict["Action"] = action
        if pin_file is not UNSET:
            field_dict["PinFile"] = pin_file
        if pin_expiration_date is not UNSET:
            field_dict["PinExpirationDate"] = pin_expiration_date

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _action = d.pop("Action", UNSET)
        action: Union[Unset, ForgotPasswordAction]
        if isinstance(_action, Unset):
            action = UNSET
        else:
            action = ForgotPasswordAction(_action)

        pin_file = d.pop("PinFile", UNSET)

        _pin_expiration_date = d.pop("PinExpirationDate", UNSET)
        pin_expiration_date: Union[Unset, None, datetime.datetime]
        if _pin_expiration_date is None:
            pin_expiration_date = None
        elif isinstance(_pin_expiration_date, Unset):
            pin_expiration_date = UNSET
        else:
            pin_expiration_date = isoparse(_pin_expiration_date)

        forgot_password_result = cls(
            action=action,
            pin_file=pin_file,
            pin_expiration_date=pin_expiration_date,
        )

        return forgot_password_result



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.image_type import ImageType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ImageProviderInfo")


@_attrs_define
class ImageProviderInfo:
    """Class ImageProviderInfo.

    Attributes:
        name (Union[Unset, str]): Gets the name.
        supported_images (Union[Unset, List[ImageType]]): Gets the supported image types.
    """

    name: Union[Unset, str] = UNSET
    supported_images: Union[Unset, List[ImageType]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        supported_images: Union[Unset, List[str]] = UNSET
        if not isinstance(self.supported_images, Unset):
            supported_images = []
            for supported_images_item_data in self.supported_images:
                supported_images_item = supported_images_item_data.value

                supported_images.append(supported_images_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if supported_images is not UNSET:
            field_dict["SupportedImages"] = supported_images

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        supported_images = []
        _supported_images = d.pop("SupportedImages", UNSET)
        for supported_images_item_data in _supported_images or []:
            supported_images_item = ImageType(supported_images_item_data)

            supported_images.append(supported_images_item)

        image_provider_info = cls(
            name=name,
            supported_images=supported_images,
        )

        return image_provider_info



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.channel_item_sort_field import ChannelItemSortField
from ..models.channel_media_content_type import ChannelMediaContentType
from ..models.channel_media_type import ChannelMediaType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ChannelFeatures")


@_attrs_define
class ChannelFeatures:
    """
    Attributes:
        name (Union[Unset, str]): Gets or sets the name.
        id (Union[Unset, str]): Gets or sets the identifier.
        can_search (Union[Unset, bool]): Gets or sets a value indicating whether this instance can search.
        media_types (Union[Unset, List[ChannelMediaType]]): Gets or sets the media types.
        content_types (Union[Unset, List[ChannelMediaContentType]]): Gets or sets the content types.
        max_page_size (Union[Unset, None, int]): Gets or sets the maximum number of records the channel allows
            retrieving at a time.
        auto_refresh_levels (Union[Unset, None, int]): Gets or sets the automatic refresh levels.
        default_sort_fields (Union[Unset, List[ChannelItemSortField]]): Gets or sets the default sort orders.
        supports_sort_order_toggle (Union[Unset, bool]): Gets or sets a value indicating whether a sort
            ascending/descending toggle is supported.
        supports_latest_media (Union[Unset, bool]): Gets or sets a value indicating whether [supports latest media].
        can_filter (Union[Unset, bool]): Gets or sets a value indicating whether this instance can filter.
        supports_content_downloading (Union[Unset, bool]): Gets or sets a value indicating whether [supports content
            downloading].
    """

    name: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    can_search: Union[Unset, bool] = UNSET
    media_types: Union[Unset, List[ChannelMediaType]] = UNSET
    content_types: Union[Unset, List[ChannelMediaContentType]] = UNSET
    max_page_size: Union[Unset, None, int] = UNSET
    auto_refresh_levels: Union[Unset, None, int] = UNSET
    default_sort_fields: Union[Unset, List[ChannelItemSortField]] = UNSET
    supports_sort_order_toggle: Union[Unset, bool] = UNSET
    supports_latest_media: Union[Unset, bool] = UNSET
    can_filter: Union[Unset, bool] = UNSET
    supports_content_downloading: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        id = self.id
        can_search = self.can_search
        media_types: Union[Unset, List[str]] = UNSET
        if not isinstance(self.media_types, Unset):
            media_types = []
            for media_types_item_data in self.media_types:
                media_types_item = media_types_item_data.value

                media_types.append(media_types_item)

        content_types: Union[Unset, List[str]] = UNSET
        if not isinstance(self.content_types, Unset):
            content_types = []
            for content_types_item_data in self.content_types:
                content_types_item = content_types_item_data.value

                content_types.append(content_types_item)

        max_page_size = self.max_page_size
        auto_refresh_levels = self.auto_refresh_levels
        default_sort_fields: Union[Unset, List[str]] = UNSET
        if not isinstance(self.default_sort_fields, Unset):
            default_sort_fields = []
            for default_sort_fields_item_data in self.default_sort_fields:
                default_sort_fields_item = default_sort_fields_item_data.value

                default_sort_fields.append(default_sort_fields_item)

        supports_sort_order_toggle = self.supports_sort_order_toggle
        supports_latest_media = self.supports_latest_media
        can_filter = self.can_filter
        supports_content_downloading = self.supports_content_downloading

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if id is not UNSET:
            field_dict["Id"] = id
        if can_search is not UNSET:
            field_dict["CanSearch"] = can_search
        if media_types is not UNSET:
            field_dict["MediaTypes"] = media_types
        if content_types is not UNSET:
            field_dict["ContentTypes"] = content_types
        if max_page_size is not UNSET:
            field_dict["MaxPageSize"] = max_page_size
        if auto_refresh_levels is not UNSET:
            field_dict["AutoRefreshLevels"] = auto_refresh_levels
        if default_sort_fields is not UNSET:
            field_dict["DefaultSortFields"] = default_sort_fields
        if supports_sort_order_toggle is not UNSET:
            field_dict["SupportsSortOrderToggle"] = supports_sort_order_toggle
        if supports_latest_media is not UNSET:
            field_dict["SupportsLatestMedia"] = supports_latest_media
        if can_filter is not UNSET:
            field_dict["CanFilter"] = can_filter
        if supports_content_downloading is not UNSET:
            field_dict["SupportsContentDownloading"] = supports_content_downloading

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        id = d.pop("Id", UNSET)

        can_search = d.pop("CanSearch", UNSET)

        media_types = []
        _media_types = d.pop("MediaTypes", UNSET)
        for media_types_item_data in _media_types or []:
            media_types_item = ChannelMediaType(media_types_item_data)

            media_types.append(media_types_item)

        content_types = []
        _content_types = d.pop("ContentTypes", UNSET)
        for content_types_item_data in _content_types or []:
            content_types_item = ChannelMediaContentType(content_types_item_data)

            content_types.append(content_types_item)

        max_page_size = d.pop("MaxPageSize", UNSET)

        auto_refresh_levels = d.pop("AutoRefreshLevels", UNSET)

        default_sort_fields = []
        _default_sort_fields = d.pop("DefaultSortFields", UNSET)
        for default_sort_fields_item_data in _default_sort_fields or []:
            default_sort_fields_item = ChannelItemSortField(default_sort_fields_item_data)

            default_sort_fields.append(default_sort_fields_item)

        supports_sort_order_toggle = d.pop("SupportsSortOrderToggle", UNSET)

        supports_latest_media = d.pop("SupportsLatestMedia", UNSET)

        can_filter = d.pop("CanFilter", UNSET)

        supports_content_downloading = d.pop("SupportsContentDownloading", UNSET)

        channel_features = cls(
            name=name,
            id=id,
            can_search=can_search,
            media_types=media_types,
            content_types=content_types,
            max_page_size=max_page_size,
            auto_refresh_levels=auto_refresh_levels,
            default_sort_fields=default_sort_fields,
            supports_sort_order_toggle=supports_sort_order_toggle,
            supports_latest_media=supports_latest_media,
            can_filter=can_filter,
            supports_content_downloading=supports_content_downloading,
        )

        return channel_features



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.notification_level import NotificationLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationsSummaryDto")


@_attrs_define
class NotificationsSummaryDto:
    """The notification summary DTO.

    Attributes:
        unread_count (Union[Unset, int]): Gets or sets the number of unread notifications.
        max_unread_notification_level (Union[Unset, None, NotificationLevel]):
    """

    unread_count: Union[Unset, int] = UNSET
    max_unread_notification_level: Union[Unset, None, NotificationLevel] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        unread_count = self.unread_count
        max_unread_notification_level: Union[Unset, None, str] = UNSET
        if not isinstance(self.max_unread_notification_level, Unset):
            max_unread_notification_level = (
                self.max_unread_notification_level.value if self.max_unread_notification_level else None
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if unread_count is not UNSET:
            field_dict["UnreadCount"] = unread_count
        if max_unread_notification_level is not UNSET:
            field_dict["MaxUnreadNotificationLevel"] = max_unread_notification_level

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        unread_count = d.pop("UnreadCount", UNSET)

        _max_unread_notification_level = d.pop("MaxUnreadNotificationLevel", UNSET)
        max_unread_notification_level: Union[Unset, None, NotificationLevel]
        if _max_unread_notification_level is None:
            max_unread_notification_level = None
        elif isinstance(_max_unread_notification_level, Unset):
            max_unread_notification_level = UNSET
        else:
            max_unread_notification_level = NotificationLevel(_max_unread_notification_level)

        notifications_summary_dto = cls(
            unread_count=unread_count,
            max_unread_notification_level=max_unread_notification_level,
        )

        return notifications_summary_dto



from typing import Any, Dict, Type, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="ForgotPasswordDto")


@_attrs_define
class ForgotPasswordDto:
    """Forgot Password request body DTO.

    Attributes:
        entered_username (str): Gets or sets the entered username to have its password reset.
    """

    entered_username: str

    def to_dict(self) -> Dict[str, Any]:
        entered_username = self.entered_username

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "EnteredUsername": entered_username,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        entered_username = d.pop("EnteredUsername")

        forgot_password_dto = cls(
            entered_username=entered_username,
        )

        return forgot_password_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="RepositoryInfo")


@_attrs_define
class RepositoryInfo:
    """Class RepositoryInfo.

    Attributes:
        name (Union[Unset, None, str]): Gets or sets the name.
        url (Union[Unset, None, str]): Gets or sets the URL.
        enabled (Union[Unset, bool]): Gets or sets a value indicating whether the repository is enabled.
    """

    name: Union[Unset, None, str] = UNSET
    url: Union[Unset, None, str] = UNSET
    enabled: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        url = self.url
        enabled = self.enabled

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if url is not UNSET:
            field_dict["Url"] = url
        if enabled is not UNSET:
            field_dict["Enabled"] = enabled

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        url = d.pop("Url", UNSET)

        enabled = d.pop("Enabled", UNSET)

        repository_info = cls(
            name=name,
            url=url,
            enabled=enabled,
        )

        return repository_info



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.group_state_type import GroupStateType
from ..types import UNSET, Unset

T = TypeVar("T", bound="GroupInfoDto")


@_attrs_define
class GroupInfoDto:
    """Class GroupInfoDto.

    Attributes:
        group_id (Union[Unset, str]): Gets the group identifier.
        group_name (Union[Unset, str]): Gets the group name.
        state (Union[Unset, GroupStateType]): Enum GroupState.
        participants (Union[Unset, List[str]]): Gets the participants.
        last_updated_at (Union[Unset, datetime.datetime]): Gets the date when this DTO has been created.
    """

    group_id: Union[Unset, str] = UNSET
    group_name: Union[Unset, str] = UNSET
    state: Union[Unset, GroupStateType] = UNSET
    participants: Union[Unset, List[str]] = UNSET
    last_updated_at: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        group_id = self.group_id
        group_name = self.group_name
        state: Union[Unset, str] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.value

        participants: Union[Unset, List[str]] = UNSET
        if not isinstance(self.participants, Unset):
            participants = self.participants

        last_updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.last_updated_at, Unset):
            last_updated_at = self.last_updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if group_id is not UNSET:
            field_dict["GroupId"] = group_id
        if group_name is not UNSET:
            field_dict["GroupName"] = group_name
        if state is not UNSET:
            field_dict["State"] = state
        if participants is not UNSET:
            field_dict["Participants"] = participants
        if last_updated_at is not UNSET:
            field_dict["LastUpdatedAt"] = last_updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        group_id = d.pop("GroupId", UNSET)

        group_name = d.pop("GroupName", UNSET)

        _state = d.pop("State", UNSET)
        state: Union[Unset, GroupStateType]
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = GroupStateType(_state)

        participants = cast(List[str], d.pop("Participants", UNSET))

        _last_updated_at = d.pop("LastUpdatedAt", UNSET)
        last_updated_at: Union[Unset, datetime.datetime]
        if isinstance(_last_updated_at, Unset):
            last_updated_at = UNSET
        else:
            last_updated_at = isoparse(_last_updated_at)

        group_info_dto = cls(
            group_id=group_id,
            group_name=group_name,
            state=state,
            participants=participants,
            last_updated_at=last_updated_at,
        )

        return group_info_dto



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="LibraryUpdateInfo")


@_attrs_define
class LibraryUpdateInfo:
    """Class LibraryUpdateInfo.

    Attributes:
        folders_added_to (Union[Unset, List[str]]): Gets or sets the folders added to.
        folders_removed_from (Union[Unset, List[str]]): Gets or sets the folders removed from.
        items_added (Union[Unset, List[str]]): Gets or sets the items added.
        items_removed (Union[Unset, List[str]]): Gets or sets the items removed.
        items_updated (Union[Unset, List[str]]): Gets or sets the items updated.
        collection_folders (Union[Unset, List[str]]):
        is_empty (Union[Unset, bool]):
    """

    folders_added_to: Union[Unset, List[str]] = UNSET
    folders_removed_from: Union[Unset, List[str]] = UNSET
    items_added: Union[Unset, List[str]] = UNSET
    items_removed: Union[Unset, List[str]] = UNSET
    items_updated: Union[Unset, List[str]] = UNSET
    collection_folders: Union[Unset, List[str]] = UNSET
    is_empty: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        folders_added_to: Union[Unset, List[str]] = UNSET
        if not isinstance(self.folders_added_to, Unset):
            folders_added_to = self.folders_added_to

        folders_removed_from: Union[Unset, List[str]] = UNSET
        if not isinstance(self.folders_removed_from, Unset):
            folders_removed_from = self.folders_removed_from

        items_added: Union[Unset, List[str]] = UNSET
        if not isinstance(self.items_added, Unset):
            items_added = self.items_added

        items_removed: Union[Unset, List[str]] = UNSET
        if not isinstance(self.items_removed, Unset):
            items_removed = self.items_removed

        items_updated: Union[Unset, List[str]] = UNSET
        if not isinstance(self.items_updated, Unset):
            items_updated = self.items_updated

        collection_folders: Union[Unset, List[str]] = UNSET
        if not isinstance(self.collection_folders, Unset):
            collection_folders = self.collection_folders

        is_empty = self.is_empty

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if folders_added_to is not UNSET:
            field_dict["FoldersAddedTo"] = folders_added_to
        if folders_removed_from is not UNSET:
            field_dict["FoldersRemovedFrom"] = folders_removed_from
        if items_added is not UNSET:
            field_dict["ItemsAdded"] = items_added
        if items_removed is not UNSET:
            field_dict["ItemsRemoved"] = items_removed
        if items_updated is not UNSET:
            field_dict["ItemsUpdated"] = items_updated
        if collection_folders is not UNSET:
            field_dict["CollectionFolders"] = collection_folders
        if is_empty is not UNSET:
            field_dict["IsEmpty"] = is_empty

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        folders_added_to = cast(List[str], d.pop("FoldersAddedTo", UNSET))

        folders_removed_from = cast(List[str], d.pop("FoldersRemovedFrom", UNSET))

        items_added = cast(List[str], d.pop("ItemsAdded", UNSET))

        items_removed = cast(List[str], d.pop("ItemsRemoved", UNSET))

        items_updated = cast(List[str], d.pop("ItemsUpdated", UNSET))

        collection_folders = cast(List[str], d.pop("CollectionFolders", UNSET))

        is_empty = d.pop("IsEmpty", UNSET)

        library_update_info = cls(
            folders_added_to=folders_added_to,
            folders_removed_from=folders_removed_from,
            items_added=items_added,
            items_removed=items_removed,
            items_updated=items_updated,
            collection_folders=collection_folders,
            is_empty=is_empty,
        )

        return library_update_info



from enum import Enum


class PlaystateCommand(str, Enum):
    FASTFORWARD = "FastForward"
    NEXTTRACK = "NextTrack"
    PAUSE = "Pause"
    PLAYPAUSE = "PlayPause"
    PREVIOUSTRACK = "PreviousTrack"
    REWIND = "Rewind"
    SEEK = "Seek"
    STOP = "Stop"
    UNPAUSE = "Unpause"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.remote_image_info import RemoteImageInfo


T = TypeVar("T", bound="RemoteImageResult")


@_attrs_define
class RemoteImageResult:
    """Class RemoteImageResult.

    Attributes:
        images (Union[Unset, None, List['RemoteImageInfo']]): Gets or sets the images.
        total_record_count (Union[Unset, int]): Gets or sets the total record count.
        providers (Union[Unset, None, List[str]]): Gets or sets the providers.
    """

    images: Union[Unset, None, List["RemoteImageInfo"]] = UNSET
    total_record_count: Union[Unset, int] = UNSET
    providers: Union[Unset, None, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        images: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            if self.images is None:
                images = None
            else:
                images = []
                for images_item_data in self.images:
                    images_item = images_item_data.to_dict()

                    images.append(images_item)

        total_record_count = self.total_record_count
        providers: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.providers, Unset):
            if self.providers is None:
                providers = None
            else:
                providers = self.providers

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if images is not UNSET:
            field_dict["Images"] = images
        if total_record_count is not UNSET:
            field_dict["TotalRecordCount"] = total_record_count
        if providers is not UNSET:
            field_dict["Providers"] = providers

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.remote_image_info import RemoteImageInfo

        d = src_dict.copy()
        images = []
        _images = d.pop("Images", UNSET)
        for images_item_data in _images or []:
            images_item = RemoteImageInfo.from_dict(images_item_data)

            images.append(images_item)

        total_record_count = d.pop("TotalRecordCount", UNSET)

        providers = cast(List[str], d.pop("Providers", UNSET))

        remote_image_result = cls(
            images=images,
            total_record_count=total_record_count,
            providers=providers,
        )

        return remote_image_result



from enum import Enum


class UnratedItem(str, Enum):
    BOOK = "Book"
    CHANNELCONTENT = "ChannelContent"
    LIVETVCHANNEL = "LiveTvChannel"
    LIVETVPROGRAM = "LiveTvProgram"
    MOVIE = "Movie"
    MUSIC = "Music"
    OTHER = "Other"
    SERIES = "Series"
    TRAILER = "Trailer"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class RecommendationType(str, Enum):
    HASACTORFROMRECENTLYPLAYED = "HasActorFromRecentlyPlayed"
    HASDIRECTORFROMRECENTLYPLAYED = "HasDirectorFromRecentlyPlayed"
    HASLIKEDACTOR = "HasLikedActor"
    HASLIKEDDIRECTOR = "HasLikedDirector"
    SIMILARTOLIKEDITEM = "SimilarToLikedItem"
    SIMILARTORECENTLYPLAYED = "SimilarToRecentlyPlayed"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="CultureDto")


@_attrs_define
class CultureDto:
    """Class CultureDto.

    Attributes:
        name (Union[Unset, str]): Gets the name.
        display_name (Union[Unset, str]): Gets the display name.
        two_letter_iso_language_name (Union[Unset, str]): Gets the name of the two letter ISO language.
        three_letter_iso_language_name (Union[Unset, None, str]): Gets the name of the three letter ISO language.
        three_letter_iso_language_names (Union[Unset, List[str]]):
    """

    name: Union[Unset, str] = UNSET
    display_name: Union[Unset, str] = UNSET
    two_letter_iso_language_name: Union[Unset, str] = UNSET
    three_letter_iso_language_name: Union[Unset, None, str] = UNSET
    three_letter_iso_language_names: Union[Unset, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        display_name = self.display_name
        two_letter_iso_language_name = self.two_letter_iso_language_name
        three_letter_iso_language_name = self.three_letter_iso_language_name
        three_letter_iso_language_names: Union[Unset, List[str]] = UNSET
        if not isinstance(self.three_letter_iso_language_names, Unset):
            three_letter_iso_language_names = self.three_letter_iso_language_names

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if display_name is not UNSET:
            field_dict["DisplayName"] = display_name
        if two_letter_iso_language_name is not UNSET:
            field_dict["TwoLetterISOLanguageName"] = two_letter_iso_language_name
        if three_letter_iso_language_name is not UNSET:
            field_dict["ThreeLetterISOLanguageName"] = three_letter_iso_language_name
        if three_letter_iso_language_names is not UNSET:
            field_dict["ThreeLetterISOLanguageNames"] = three_letter_iso_language_names

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        display_name = d.pop("DisplayName", UNSET)

        two_letter_iso_language_name = d.pop("TwoLetterISOLanguageName", UNSET)

        three_letter_iso_language_name = d.pop("ThreeLetterISOLanguageName", UNSET)

        three_letter_iso_language_names = cast(List[str], d.pop("ThreeLetterISOLanguageNames", UNSET))

        culture_dto = cls(
            name=name,
            display_name=display_name,
            two_letter_iso_language_name=two_letter_iso_language_name,
            three_letter_iso_language_name=three_letter_iso_language_name,
            three_letter_iso_language_names=three_letter_iso_language_names,
        )

        return culture_dto



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.name_guid_pair import NameGuidPair


T = TypeVar("T", bound="QueryFilters")


@_attrs_define
class QueryFilters:
    """
    Attributes:
        genres (Union[Unset, None, List['NameGuidPair']]):
        tags (Union[Unset, None, List[str]]):
    """

    genres: Union[Unset, None, List["NameGuidPair"]] = UNSET
    tags: Union[Unset, None, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        genres: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.genres, Unset):
            if self.genres is None:
                genres = None
            else:
                genres = []
                for genres_item_data in self.genres:
                    genres_item = genres_item_data.to_dict()

                    genres.append(genres_item)

        tags: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            if self.tags is None:
                tags = None
            else:
                tags = self.tags

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if genres is not UNSET:
            field_dict["Genres"] = genres
        if tags is not UNSET:
            field_dict["Tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.name_guid_pair import NameGuidPair

        d = src_dict.copy()
        genres = []
        _genres = d.pop("Genres", UNSET)
        for genres_item_data in _genres or []:
            genres_item = NameGuidPair.from_dict(genres_item_data)

            genres.append(genres_item)

        tags = cast(List[str], d.pop("Tags", UNSET))

        query_filters = cls(
            genres=genres,
            tags=tags,
        )

        return query_filters



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ClientLogDocumentResponseDto")


@_attrs_define
class ClientLogDocumentResponseDto:
    """Client log document response dto.

    Attributes:
        file_name (Union[Unset, str]): Gets the resulting filename.
    """

    file_name: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        file_name = self.file_name

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if file_name is not UNSET:
            field_dict["FileName"] = file_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        file_name = d.pop("FileName", UNSET)

        client_log_document_response_dto = cls(
            file_name=file_name,
        )

        return client_log_document_response_dto



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.embedded_subtitle_options import EmbeddedSubtitleOptions
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.media_path_info import MediaPathInfo
    from ..models.type_options import TypeOptions


T = TypeVar("T", bound="LibraryOptions")


@_attrs_define
class LibraryOptions:
    """
    Attributes:
        enable_photos (Union[Unset, bool]):
        enable_realtime_monitor (Union[Unset, bool]):
        enable_chapter_image_extraction (Union[Unset, bool]):
        extract_chapter_images_during_library_scan (Union[Unset, bool]):
        path_infos (Union[Unset, List['MediaPathInfo']]):
        save_local_metadata (Union[Unset, bool]):
        enable_internet_providers (Union[Unset, bool]):
        enable_automatic_series_grouping (Union[Unset, bool]):
        enable_embedded_titles (Union[Unset, bool]):
        enable_embedded_episode_infos (Union[Unset, bool]):
        automatic_refresh_interval_days (Union[Unset, int]):
        preferred_metadata_language (Union[Unset, None, str]): Gets or sets the preferred metadata language.
        metadata_country_code (Union[Unset, None, str]): Gets or sets the metadata country code.
        season_zero_display_name (Union[Unset, str]):
        metadata_savers (Union[Unset, None, List[str]]):
        disabled_local_metadata_readers (Union[Unset, List[str]]):
        local_metadata_reader_order (Union[Unset, None, List[str]]):
        disabled_subtitle_fetchers (Union[Unset, List[str]]):
        subtitle_fetcher_order (Union[Unset, List[str]]):
        skip_subtitles_if_embedded_subtitles_present (Union[Unset, bool]):
        skip_subtitles_if_audio_track_matches (Union[Unset, bool]):
        subtitle_download_languages (Union[Unset, None, List[str]]):
        require_perfect_subtitle_match (Union[Unset, bool]):
        save_subtitles_with_media (Union[Unset, bool]):
        automatically_add_to_collection (Union[Unset, bool]):
        allow_embedded_subtitles (Union[Unset, EmbeddedSubtitleOptions]): An enum representing the options to disable
            embedded subs.
        type_options (Union[Unset, List['TypeOptions']]):
    """

    enable_photos: Union[Unset, bool] = UNSET
    enable_realtime_monitor: Union[Unset, bool] = UNSET
    enable_chapter_image_extraction: Union[Unset, bool] = UNSET
    extract_chapter_images_during_library_scan: Union[Unset, bool] = UNSET
    path_infos: Union[Unset, List["MediaPathInfo"]] = UNSET
    save_local_metadata: Union[Unset, bool] = UNSET
    enable_internet_providers: Union[Unset, bool] = UNSET
    enable_automatic_series_grouping: Union[Unset, bool] = UNSET
    enable_embedded_titles: Union[Unset, bool] = UNSET
    enable_embedded_episode_infos: Union[Unset, bool] = UNSET
    automatic_refresh_interval_days: Union[Unset, int] = UNSET
    preferred_metadata_language: Union[Unset, None, str] = UNSET
    metadata_country_code: Union[Unset, None, str] = UNSET
    season_zero_display_name: Union[Unset, str] = UNSET
    metadata_savers: Union[Unset, None, List[str]] = UNSET
    disabled_local_metadata_readers: Union[Unset, List[str]] = UNSET
    local_metadata_reader_order: Union[Unset, None, List[str]] = UNSET
    disabled_subtitle_fetchers: Union[Unset, List[str]] = UNSET
    subtitle_fetcher_order: Union[Unset, List[str]] = UNSET
    skip_subtitles_if_embedded_subtitles_present: Union[Unset, bool] = UNSET
    skip_subtitles_if_audio_track_matches: Union[Unset, bool] = UNSET
    subtitle_download_languages: Union[Unset, None, List[str]] = UNSET
    require_perfect_subtitle_match: Union[Unset, bool] = UNSET
    save_subtitles_with_media: Union[Unset, bool] = UNSET
    automatically_add_to_collection: Union[Unset, bool] = UNSET
    allow_embedded_subtitles: Union[Unset, EmbeddedSubtitleOptions] = UNSET
    type_options: Union[Unset, List["TypeOptions"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        enable_photos = self.enable_photos
        enable_realtime_monitor = self.enable_realtime_monitor
        enable_chapter_image_extraction = self.enable_chapter_image_extraction
        extract_chapter_images_during_library_scan = self.extract_chapter_images_during_library_scan
        path_infos: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.path_infos, Unset):
            path_infos = []
            for path_infos_item_data in self.path_infos:
                path_infos_item = path_infos_item_data.to_dict()

                path_infos.append(path_infos_item)

        save_local_metadata = self.save_local_metadata
        enable_internet_providers = self.enable_internet_providers
        enable_automatic_series_grouping = self.enable_automatic_series_grouping
        enable_embedded_titles = self.enable_embedded_titles
        enable_embedded_episode_infos = self.enable_embedded_episode_infos
        automatic_refresh_interval_days = self.automatic_refresh_interval_days
        preferred_metadata_language = self.preferred_metadata_language
        metadata_country_code = self.metadata_country_code
        season_zero_display_name = self.season_zero_display_name
        metadata_savers: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.metadata_savers, Unset):
            if self.metadata_savers is None:
                metadata_savers = None
            else:
                metadata_savers = self.metadata_savers

        disabled_local_metadata_readers: Union[Unset, List[str]] = UNSET
        if not isinstance(self.disabled_local_metadata_readers, Unset):
            disabled_local_metadata_readers = self.disabled_local_metadata_readers

        local_metadata_reader_order: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.local_metadata_reader_order, Unset):
            if self.local_metadata_reader_order is None:
                local_metadata_reader_order = None
            else:
                local_metadata_reader_order = self.local_metadata_reader_order

        disabled_subtitle_fetchers: Union[Unset, List[str]] = UNSET
        if not isinstance(self.disabled_subtitle_fetchers, Unset):
            disabled_subtitle_fetchers = self.disabled_subtitle_fetchers

        subtitle_fetcher_order: Union[Unset, List[str]] = UNSET
        if not isinstance(self.subtitle_fetcher_order, Unset):
            subtitle_fetcher_order = self.subtitle_fetcher_order

        skip_subtitles_if_embedded_subtitles_present = self.skip_subtitles_if_embedded_subtitles_present
        skip_subtitles_if_audio_track_matches = self.skip_subtitles_if_audio_track_matches
        subtitle_download_languages: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.subtitle_download_languages, Unset):
            if self.subtitle_download_languages is None:
                subtitle_download_languages = None
            else:
                subtitle_download_languages = self.subtitle_download_languages

        require_perfect_subtitle_match = self.require_perfect_subtitle_match
        save_subtitles_with_media = self.save_subtitles_with_media
        automatically_add_to_collection = self.automatically_add_to_collection
        allow_embedded_subtitles: Union[Unset, str] = UNSET
        if not isinstance(self.allow_embedded_subtitles, Unset):
            allow_embedded_subtitles = self.allow_embedded_subtitles.value

        type_options: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.type_options, Unset):
            type_options = []
            for type_options_item_data in self.type_options:
                type_options_item = type_options_item_data.to_dict()

                type_options.append(type_options_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if enable_photos is not UNSET:
            field_dict["EnablePhotos"] = enable_photos
        if enable_realtime_monitor is not UNSET:
            field_dict["EnableRealtimeMonitor"] = enable_realtime_monitor
        if enable_chapter_image_extraction is not UNSET:
            field_dict["EnableChapterImageExtraction"] = enable_chapter_image_extraction
        if extract_chapter_images_during_library_scan is not UNSET:
            field_dict["ExtractChapterImagesDuringLibraryScan"] = extract_chapter_images_during_library_scan
        if path_infos is not UNSET:
            field_dict["PathInfos"] = path_infos
        if save_local_metadata is not UNSET:
            field_dict["SaveLocalMetadata"] = save_local_metadata
        if enable_internet_providers is not UNSET:
            field_dict["EnableInternetProviders"] = enable_internet_providers
        if enable_automatic_series_grouping is not UNSET:
            field_dict["EnableAutomaticSeriesGrouping"] = enable_automatic_series_grouping
        if enable_embedded_titles is not UNSET:
            field_dict["EnableEmbeddedTitles"] = enable_embedded_titles
        if enable_embedded_episode_infos is not UNSET:
            field_dict["EnableEmbeddedEpisodeInfos"] = enable_embedded_episode_infos
        if automatic_refresh_interval_days is not UNSET:
            field_dict["AutomaticRefreshIntervalDays"] = automatic_refresh_interval_days
        if preferred_metadata_language is not UNSET:
            field_dict["PreferredMetadataLanguage"] = preferred_metadata_language
        if metadata_country_code is not UNSET:
            field_dict["MetadataCountryCode"] = metadata_country_code
        if season_zero_display_name is not UNSET:
            field_dict["SeasonZeroDisplayName"] = season_zero_display_name
        if metadata_savers is not UNSET:
            field_dict["MetadataSavers"] = metadata_savers
        if disabled_local_metadata_readers is not UNSET:
            field_dict["DisabledLocalMetadataReaders"] = disabled_local_metadata_readers
        if local_metadata_reader_order is not UNSET:
            field_dict["LocalMetadataReaderOrder"] = local_metadata_reader_order
        if disabled_subtitle_fetchers is not UNSET:
            field_dict["DisabledSubtitleFetchers"] = disabled_subtitle_fetchers
        if subtitle_fetcher_order is not UNSET:
            field_dict["SubtitleFetcherOrder"] = subtitle_fetcher_order
        if skip_subtitles_if_embedded_subtitles_present is not UNSET:
            field_dict["SkipSubtitlesIfEmbeddedSubtitlesPresent"] = skip_subtitles_if_embedded_subtitles_present
        if skip_subtitles_if_audio_track_matches is not UNSET:
            field_dict["SkipSubtitlesIfAudioTrackMatches"] = skip_subtitles_if_audio_track_matches
        if subtitle_download_languages is not UNSET:
            field_dict["SubtitleDownloadLanguages"] = subtitle_download_languages
        if require_perfect_subtitle_match is not UNSET:
            field_dict["RequirePerfectSubtitleMatch"] = require_perfect_subtitle_match
        if save_subtitles_with_media is not UNSET:
            field_dict["SaveSubtitlesWithMedia"] = save_subtitles_with_media
        if automatically_add_to_collection is not UNSET:
            field_dict["AutomaticallyAddToCollection"] = automatically_add_to_collection
        if allow_embedded_subtitles is not UNSET:
            field_dict["AllowEmbeddedSubtitles"] = allow_embedded_subtitles
        if type_options is not UNSET:
            field_dict["TypeOptions"] = type_options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_path_info import MediaPathInfo
        from ..models.type_options import TypeOptions

        d = src_dict.copy()
        enable_photos = d.pop("EnablePhotos", UNSET)

        enable_realtime_monitor = d.pop("EnableRealtimeMonitor", UNSET)

        enable_chapter_image_extraction = d.pop("EnableChapterImageExtraction", UNSET)

        extract_chapter_images_during_library_scan = d.pop("ExtractChapterImagesDuringLibraryScan", UNSET)

        path_infos = []
        _path_infos = d.pop("PathInfos", UNSET)
        for path_infos_item_data in _path_infos or []:
            path_infos_item = MediaPathInfo.from_dict(path_infos_item_data)

            path_infos.append(path_infos_item)

        save_local_metadata = d.pop("SaveLocalMetadata", UNSET)

        enable_internet_providers = d.pop("EnableInternetProviders", UNSET)

        enable_automatic_series_grouping = d.pop("EnableAutomaticSeriesGrouping", UNSET)

        enable_embedded_titles = d.pop("EnableEmbeddedTitles", UNSET)

        enable_embedded_episode_infos = d.pop("EnableEmbeddedEpisodeInfos", UNSET)

        automatic_refresh_interval_days = d.pop("AutomaticRefreshIntervalDays", UNSET)

        preferred_metadata_language = d.pop("PreferredMetadataLanguage", UNSET)

        metadata_country_code = d.pop("MetadataCountryCode", UNSET)

        season_zero_display_name = d.pop("SeasonZeroDisplayName", UNSET)

        metadata_savers = cast(List[str], d.pop("MetadataSavers", UNSET))

        disabled_local_metadata_readers = cast(List[str], d.pop("DisabledLocalMetadataReaders", UNSET))

        local_metadata_reader_order = cast(List[str], d.pop("LocalMetadataReaderOrder", UNSET))

        disabled_subtitle_fetchers = cast(List[str], d.pop("DisabledSubtitleFetchers", UNSET))

        subtitle_fetcher_order = cast(List[str], d.pop("SubtitleFetcherOrder", UNSET))

        skip_subtitles_if_embedded_subtitles_present = d.pop("SkipSubtitlesIfEmbeddedSubtitlesPresent", UNSET)

        skip_subtitles_if_audio_track_matches = d.pop("SkipSubtitlesIfAudioTrackMatches", UNSET)

        subtitle_download_languages = cast(List[str], d.pop("SubtitleDownloadLanguages", UNSET))

        require_perfect_subtitle_match = d.pop("RequirePerfectSubtitleMatch", UNSET)

        save_subtitles_with_media = d.pop("SaveSubtitlesWithMedia", UNSET)

        automatically_add_to_collection = d.pop("AutomaticallyAddToCollection", UNSET)

        _allow_embedded_subtitles = d.pop("AllowEmbeddedSubtitles", UNSET)
        allow_embedded_subtitles: Union[Unset, EmbeddedSubtitleOptions]
        if isinstance(_allow_embedded_subtitles, Unset):
            allow_embedded_subtitles = UNSET
        else:
            allow_embedded_subtitles = EmbeddedSubtitleOptions(_allow_embedded_subtitles)

        type_options = []
        _type_options = d.pop("TypeOptions", UNSET)
        for type_options_item_data in _type_options or []:
            type_options_item = TypeOptions.from_dict(type_options_item_data)

            type_options.append(type_options_item)

        library_options = cls(
            enable_photos=enable_photos,
            enable_realtime_monitor=enable_realtime_monitor,
            enable_chapter_image_extraction=enable_chapter_image_extraction,
            extract_chapter_images_during_library_scan=extract_chapter_images_during_library_scan,
            path_infos=path_infos,
            save_local_metadata=save_local_metadata,
            enable_internet_providers=enable_internet_providers,
            enable_automatic_series_grouping=enable_automatic_series_grouping,
            enable_embedded_titles=enable_embedded_titles,
            enable_embedded_episode_infos=enable_embedded_episode_infos,
            automatic_refresh_interval_days=automatic_refresh_interval_days,
            preferred_metadata_language=preferred_metadata_language,
            metadata_country_code=metadata_country_code,
            season_zero_display_name=season_zero_display_name,
            metadata_savers=metadata_savers,
            disabled_local_metadata_readers=disabled_local_metadata_readers,
            local_metadata_reader_order=local_metadata_reader_order,
            disabled_subtitle_fetchers=disabled_subtitle_fetchers,
            subtitle_fetcher_order=subtitle_fetcher_order,
            skip_subtitles_if_embedded_subtitles_present=skip_subtitles_if_embedded_subtitles_present,
            skip_subtitles_if_audio_track_matches=skip_subtitles_if_audio_track_matches,
            subtitle_download_languages=subtitle_download_languages,
            require_perfect_subtitle_match=require_perfect_subtitle_match,
            save_subtitles_with_media=save_subtitles_with_media,
            automatically_add_to_collection=automatically_add_to_collection,
            allow_embedded_subtitles=allow_embedded_subtitles,
            type_options=type_options,
        )

        return library_options



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="FontFile")


@_attrs_define
class FontFile:
    """Class FontFile.

    Attributes:
        name (Union[Unset, None, str]): Gets or sets the name.
        size (Union[Unset, int]): Gets or sets the size.
        date_created (Union[Unset, datetime.datetime]): Gets or sets the date created.
        date_modified (Union[Unset, datetime.datetime]): Gets or sets the date modified.
    """

    name: Union[Unset, None, str] = UNSET
    size: Union[Unset, int] = UNSET
    date_created: Union[Unset, datetime.datetime] = UNSET
    date_modified: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        size = self.size
        date_created: Union[Unset, str] = UNSET
        if not isinstance(self.date_created, Unset):
            date_created = self.date_created.isoformat()

        date_modified: Union[Unset, str] = UNSET
        if not isinstance(self.date_modified, Unset):
            date_modified = self.date_modified.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if size is not UNSET:
            field_dict["Size"] = size
        if date_created is not UNSET:
            field_dict["DateCreated"] = date_created
        if date_modified is not UNSET:
            field_dict["DateModified"] = date_modified

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        size = d.pop("Size", UNSET)

        _date_created = d.pop("DateCreated", UNSET)
        date_created: Union[Unset, datetime.datetime]
        if isinstance(_date_created, Unset):
            date_created = UNSET
        else:
            date_created = isoparse(_date_created)

        _date_modified = d.pop("DateModified", UNSET)
        date_modified: Union[Unset, datetime.datetime]
        if isinstance(_date_modified, Unset):
            date_modified = UNSET
        else:
            date_modified = isoparse(_date_modified)

        font_file = cls(
            name=name,
            size=size,
            date_created=date_created,
            date_modified=date_modified,
        )

        return font_file
